"""


Mesh Delimit Mode Items
^^^^^^^^^^^^^^^^^^^^^^^

:NORMAL:          
  Normal.

  Delimit by face directions.

:MATERIAL:        
  Material.

  Delimit by face material.

:SEAM:            
  Seam.

  Delimit by edge seams.

:SHARP:           
  Sharp.

  Delimit by sharp edges.

:UV:              
  UVs.

  Delimit by UV coordinates.

.. _rna-enum-mesh-delimit-mode-items:

"""

import typing



"""


Freestyle Predicates (freestyle.predicates)
*******************************************

This module contains predicates operating on vertices (0D elements)
and polylines (1D elements).  It is also intended to be a collection
of examples for predicate definition in Python.

User-defined predicates inherit one of the following base classes,
depending on the object type (0D or 1D) to operate on and the arity
(unary or binary):

* :class:`freestyle.types.BinaryPredicate0D`

* :class:`freestyle.types.BinaryPredicate1D`

* :class:`freestyle.types.UnaryPredicate0D`

* :class:`freestyle.types.UnaryPredicate1D`

:class:`AndBP1D`

:class:`AndUP1D`

:class:`ContourUP1D`

:class:`DensityLowerThanUP1D`

:class:`EqualToChainingTimeStampUP1D`

:class:`EqualToTimeStampUP1D`

:class:`ExternalContourUP1D`

:class:`FalseBP1D`

:class:`FalseUP0D`

:class:`FalseUP1D`

:class:`Length2DBP1D`

:class:`MaterialBP1D`

:class:`NotBP1D`

:class:`NotUP1D`

:class:`ObjectNamesUP1D`

:class:`OrBP1D`

:class:`OrUP1D`

:class:`QuantitativeInvisibilityRangeUP1D`

:class:`QuantitativeInvisibilityUP1D`

:class:`SameShapeIdBP1D`

:class:`ShapeUP1D`

:class:`TrueBP1D`

:class:`TrueUP0D`

:class:`TrueUP1D`

:class:`ViewMapGradientNormBP1D`

:class:`WithinImageBoundaryUP1D`

:class:`pyBackTVertexUP0D`

:class:`pyClosedCurveUP1D`

:class:`pyDensityFunctorUP1D`

:class:`pyDensityUP1D`

:class:`pyDensityVariableSigmaUP1D`

:class:`pyHighDensityAnisotropyUP1D`

:class:`pyHighDirectionalViewMapDensityUP1D`

:class:`pyHighSteerableViewMapDensityUP1D`

:class:`pyHighViewMapDensityUP1D`

:class:`pyHighViewMapGradientNormUP1D`

:class:`pyHigherCurvature2DAngleUP0D`

:class:`pyHigherLengthUP1D`

:class:`pyHigherNumberOfTurnsUP1D`

:class:`pyIsInOccludersListUP1D`

:class:`pyIsOccludedByIdListUP1D`

:class:`pyIsOccludedByItselfUP1D`

:class:`pyIsOccludedByUP1D`

:class:`pyLengthBP1D`

:class:`pyLowDirectionalViewMapDensityUP1D`

:class:`pyLowSteerableViewMapDensityUP1D`

:class:`pyNFirstUP1D`

:class:`pyNatureBP1D`

:class:`pyNatureUP1D`

:class:`pyParameterUP0D`

:class:`pyParameterUP0DGoodOne`

:class:`pyProjectedXBP1D`

:class:`pyProjectedYBP1D`

:class:`pyShapeIdListUP1D`

:class:`pyShapeIdUP1D`

:class:`pyShuffleBP1D`

:class:`pySilhouetteFirstBP1D`

:class:`pyUEqualsUP0D`

:class:`pyVertexNatureUP0D`

:class:`pyViewMapGradientNormBP1D`

:class:`pyZBP1D`

:class:`pyZDiscontinuityBP1D`

:class:`pyZSmallerUP1D`

"""

import typing

import freestyle

class AndBP1D:

  ...

class AndUP1D:

  ...

class ContourUP1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate1D` > :class:`ContourUP1D`

  """

  def __call__(self, inter: freestyle.types.Interface1D) -> bool:

    """

    Returns true if the Interface1D is a contour. An Interface1D is a
contour if it is bordered by a different shape on each of its sides.

    """

    ...

class DensityLowerThanUP1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate1D` > :class:`DensityLowerThanUP1D`

  """

  def __init__(self, threshold: float, sigma: float = 2.0) -> None:

    """

    Builds a DensityLowerThanUP1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> bool:

    """

    Returns true if the density evaluated for the Interface1D is less
than a user-defined density value.

    """

    ...

class EqualToChainingTimeStampUP1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate1D` > :class:`freestyle.types.EqualToChainingTimeStampUP1D`

  """

  def __init__(self, ts: int) -> None:

    """

    Builds a EqualToChainingTimeStampUP1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> bool:

    """

    Returns true if the Interface1D's time stamp is equal to a certain
user-defined value.

    """

    ...

class EqualToTimeStampUP1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate1D` > :class:`EqualToTimeStampUP1D`

  """

  def __init__(self, ts: int) -> None:

    """

    Builds a EqualToTimeStampUP1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> bool:

    """

    Returns true if the Interface1D's time stamp is equal to a certain
user-defined value.

    """

    ...

class ExternalContourUP1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate1D` > :class:`ExternalContourUP1D`

  """

  def __call__(self, inter: freestyle.types.Interface1D) -> bool:

    """

    Returns true if the Interface1D is an external contour.
An Interface1D is an external contour if it is bordered by no shape on
one of its sides.

    """

    ...

class FalseBP1D:

  """

  Class hierarchy: :class:`freestyle.types.BinaryPredicate1D` > :class:`FalseBP1D`

  """

  def __call__(self, inter1: freestyle.types.Interface1D, inter2: freestyle.types.Interface1D) -> bool:

    """

    Always returns false.

    """

    ...

class FalseUP0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate0D` > :class:`FalseUP0D`

  """

  def __call__(self, it: freestyle.types.Interface0DIterator) -> bool:

    """

    Always returns false.

    """

    ...

class FalseUP1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate1D` > :class:`FalseUP1D`

  """

  def __call__(self, inter: freestyle.types.Interface1D) -> bool:

    """

    Always returns false.

    """

    ...

class Length2DBP1D:

  """

  Class hierarchy: :class:`freestyle.types.BinaryPredicate1D` > :class:`Length2DBP1D`

  """

  def __call__(self, inter1: freestyle.types.Interface1D, inter2: freestyle.types.Interface1D) -> bool:

    """

    Returns true if the 2D length of inter1 is less than the 2D length
of inter2.

    """

    ...

class MaterialBP1D:

  """

  Checks whether the two supplied ViewEdges have the same material.

  """

  ...

class NotBP1D:

  ...

class NotUP1D:

  ...

class ObjectNamesUP1D:

  ...

class OrBP1D:

  ...

class OrUP1D:

  ...

class QuantitativeInvisibilityRangeUP1D:

  ...

class QuantitativeInvisibilityUP1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate1D` > :class:`QuantitativeInvisibilityUP1D`

  """

  def __init__(self, qi: int = 0) -> None:

    """

    Builds a QuantitativeInvisibilityUP1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> bool:

    """

    Returns true if the Quantitative Invisibility evaluated at an
Interface1D, using the
:class:`freestyle.functions.QuantitativeInvisibilityF1D` functor,
equals a certain user-defined value.

    """

    ...

class SameShapeIdBP1D:

  """

  Class hierarchy: :class:`freestyle.types.BinaryPredicate1D` > :class:`SameShapeIdBP1D`

  """

  def __call__(self, inter1: freestyle.types.Interface1D, inter2: freestyle.types.Interface1D) -> bool:

    """

    Returns true if inter1 and inter2 belong to the same shape.

    """

    ...

class ShapeUP1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate1D` > :class:`ShapeUP1D`

  """

  def __init__(self, first: int, second: int = 0) -> None:

    """

    Builds a ShapeUP1D object.

    """

    ...

  def __call__(self, inter: freestyle.types.Interface1D) -> bool:

    """

    Returns true if the shape to which the Interface1D belongs to has the
same :class:`freestyle.types.Id` as the one specified by the user.

    """

    ...

class TrueBP1D:

  """

  Class hierarchy: :class:`freestyle.types.BinaryPredicate1D` > :class:`TrueBP1D`

  """

  def __call__(self, inter1: freestyle.types.Interface1D, inter2: freestyle.types.Interface1D) -> bool:

    """

    Always returns true.

    """

    ...

class TrueUP0D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate0D` > :class:`TrueUP0D`

  """

  def __call__(self, it: freestyle.types.Interface0DIterator) -> bool:

    """

    Always returns true.

    """

    ...

class TrueUP1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate1D` > :class:`TrueUP1D`

  """

  def __call__(self, inter: freestyle.types.Interface1D) -> bool:

    """

    Always returns true.

    """

    ...

class ViewMapGradientNormBP1D:

  """

  Class hierarchy: :class:`freestyle.types.BinaryPredicate1D` > :class:`ViewMapGradientNormBP1D`

  """

  def __init__(self, level: int, integration_type: freestyle.types.IntegrationType = IntegrationType.MEAN, sampling: float = 2.0) -> None:

    """

    Builds a ViewMapGradientNormBP1D object.

    """

    ...

  def __call__(self, inter1: freestyle.types.Interface1D, inter2: freestyle.types.Interface1D) -> bool:

    """

    Returns true if the evaluation of the Gradient norm Function is
higher for inter1 than for inter2.

    """

    ...

class WithinImageBoundaryUP1D:

  """

  Class hierarchy: :class:`freestyle.types.UnaryPredicate1D` > :class:`WithinImageBoundaryUP1D`

  """

  def __init__(self, xmin: float, ymin: float, xmax: float, ymax: float) -> None:

    """

    Builds an WithinImageBoundaryUP1D object.

    """

    ...

  def __call__(self, inter: typing.Any) -> None:

    """

    Returns true if the Interface1D intersects with image boundary.

    """

    ...

class pyBackTVertexUP0D:

  """

  Check whether an Interface0DIterator references a TVertex and is
the one that is hidden (inferred from the context).

  """

  ...

class pyClosedCurveUP1D:

  ...

class pyDensityFunctorUP1D:

  ...

class pyDensityUP1D:

  ...

class pyDensityVariableSigmaUP1D:

  ...

class pyHighDensityAnisotropyUP1D:

  ...

class pyHighDirectionalViewMapDensityUP1D:

  ...

class pyHighSteerableViewMapDensityUP1D:

  ...

class pyHighViewMapDensityUP1D:

  ...

class pyHighViewMapGradientNormUP1D:

  ...

class pyHigherCurvature2DAngleUP0D:

  ...

class pyHigherLengthUP1D:

  ...

class pyHigherNumberOfTurnsUP1D:

  ...

class pyIsInOccludersListUP1D:

  ...

class pyIsOccludedByIdListUP1D:

  ...

class pyIsOccludedByItselfUP1D:

  ...

class pyIsOccludedByUP1D:

  ...

class pyLengthBP1D:

  ...

class pyLowDirectionalViewMapDensityUP1D:

  ...

class pyLowSteerableViewMapDensityUP1D:

  ...

class pyNFirstUP1D:

  ...

class pyNatureBP1D:

  ...

class pyNatureUP1D:

  ...

class pyParameterUP0D:

  ...

class pyParameterUP0DGoodOne:

  ...

class pyProjectedXBP1D:

  ...

class pyProjectedYBP1D:

  ...

class pyShapeIdListUP1D:

  ...

class pyShapeIdUP1D:

  ...

class pyShuffleBP1D:

  ...

class pySilhouetteFirstBP1D:

  ...

class pyUEqualsUP0D:

  ...

class pyVertexNatureUP0D:

  ...

class pyViewMapGradientNormBP1D:

  ...

class pyZBP1D:

  ...

class pyZDiscontinuityBP1D:

  ...

class pyZSmallerUP1D:

  ...



"""


GPU Capabilities Utilities (gpu.capabilities)
*********************************************

This module provides access to the GPU capabilities.

:func:`compute_shader_support_get`

:func:`extensions_get`

:func:`hdr_support_get`

:func:`max_batch_indices_get`

:func:`max_batch_vertices_get`

:func:`max_texture_layers_get`

:func:`max_texture_size_get`

:func:`max_textures_frag_get`

:func:`max_textures_geom_get`

:func:`max_textures_get`

:func:`max_textures_vert_get`

:func:`max_uniforms_frag_get`

:func:`max_uniforms_vert_get`

:func:`max_varying_floats_get`

:func:`max_vertex_attribs_get`

:func:`shader_image_load_store_support_get`

:func:`shader_storage_buffer_objects_support_get`

"""

import typing

def compute_shader_support_get() -> bool:

  """

  Are compute shaders supported.

  """

  ...

def extensions_get() -> typing.Tuple[str, ...]:

  """

  Get supported extensions in the current context.

  """

  ...

def hdr_support_get() -> bool:

  """

  Return whether GPU backend supports High Dynamic range for viewport.

  """

  ...

def max_batch_indices_get() -> int:

  """

  Get maximum number of vertex array indices.

  """

  ...

def max_batch_vertices_get() -> int:

  """

  Get maximum number of vertex array vertices.

  """

  ...

def max_texture_layers_get() -> int:

  """

  Get maximum number of layers in texture.

  """

  ...

def max_texture_size_get() -> int:

  """

  Get estimated maximum texture size to be able to handle.

  """

  ...

def max_textures_frag_get() -> int:

  """

  Get maximum supported texture image units used for
accessing texture maps from the fragment shader.

  """

  ...

def max_textures_geom_get() -> int:

  """

  Get maximum supported texture image units used for
accessing texture maps from the geometry shader.

  """

  ...

def max_textures_get() -> int:

  """

  Get maximum supported texture image units used for
accessing texture maps from the vertex shader and the
fragment processor.

  """

  ...

def max_textures_vert_get() -> int:

  """

  Get maximum supported texture image units used for
accessing texture maps from the vertex shader.

  """

  ...

def max_uniforms_frag_get() -> int:

  """

  Get maximum number of values held in uniform variable
storage for a fragment shader.

  """

  ...

def max_uniforms_vert_get() -> int:

  """

  Get maximum number of values held in uniform variable
storage for a vertex shader.

  """

  ...

def max_varying_floats_get() -> int:

  """

  Get maximum number of varying variables used by
vertex and fragment shaders.

  """

  ...

def max_vertex_attribs_get() -> int:

  """

  Get maximum number of vertex attributes accessible to
a vertex shader.

  """

  ...

def shader_image_load_store_support_get() -> bool:

  """

  Is image load/store supported.

  """

  ...

def shader_storage_buffer_objects_support_get() -> bool:

  """

  Are SSBO's supported.

  """

  ...



"""


Metaelem Type Items
^^^^^^^^^^^^^^^^^^^

:BALL:            
  Ball.

:CAPSULE:         
  Capsule.

:PLANE:           
  Plane.

:ELLIPSOID:       
  Ellipsoid.

:CUBE:            
  Cube.

.. _rna-enum-metaelem-type-items:

"""

import typing



"""


Attribute Domain Edge Face Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:EDGE:            
  Edge.

  Attribute on mesh edge.

:FACE:            
  Face.

  Attribute on mesh faces.

.. _rna-enum-attribute-domain-edge-face-items:

"""

import typing



"""


Node Geometry Mesh Circle Fill Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

:NGON:            
  N-Gon.

:TRIANGLE_FAN:    
  Triangles.

.. _rna-enum-node-geometry-mesh-circle-fill-type-items:

"""

import typing



"""


Event Type Items
^^^^^^^^^^^^^^^^

:NONE:            
:LEFTMOUSE:       
  Left Mouse.

  LMB.

:MIDDLEMOUSE:     
  Middle Mouse.

  MMB.

:RIGHTMOUSE:      
  Right Mouse.

  RMB.

:BUTTON4MOUSE:    
  Button4 Mouse.

  MB4.

:BUTTON5MOUSE:    
  Button5 Mouse.

  MB5.

:BUTTON6MOUSE:    
  Button6 Mouse.

  MB6.

:BUTTON7MOUSE:    
  Button7 Mouse.

  MB7.

.. _rna-enum-event-type-items:

======================================================================

:PEN:             
  Pen.

:ERASER:          
  Eraser.

======================================================================

:MOUSEMOVE:       
  Mouse Move.

  MsMov.

:INBETWEEN_MOUSEMOVE:
  In-between Move.

  MsSubMov.

:TRACKPADPAN:     
  Mouse/Trackpad Pan.

  MsPan.

:TRACKPADZOOM:    
  Mouse/Trackpad Zoom.

  MsZoom.

:MOUSEROTATE:     
  Mouse/Trackpad Rotate.

  MsRot.

:MOUSESMARTZOOM:  
  Mouse/Trackpad Smart Zoom.

  MsSmartZoom.

======================================================================

:WHEELUPMOUSE:    
  Wheel Up.

  WhUp.

:WHEELDOWNMOUSE:  
  Wheel Down.

  WhDown.

:WHEELINMOUSE:    
  Wheel In.

  WhIn.

:WHEELOUTMOUSE:   
  Wheel Out.

  WhOut.

======================================================================

:A:               
:B:               
:C:               
:D:               
:E:               
:F:               
:G:               
:H:               
:I:               
:J:               
:K:               
:L:               
:M:               
:N:               
:O:               
:P:               
:Q:               
:R:               
:S:               
:T:               
:U:               
:V:               
:W:               
:X:               
:Y:               
:Z:               
======================================================================

:ZERO:            
:ONE:             
:TWO:             
:THREE:           
:FOUR:            
:FIVE:            
:SIX:             
:SEVEN:           
:EIGHT:           
:NINE:            
======================================================================

:LEFT_CTRL:       
  Left Ctrl.

  CtrlL.

:LEFT_ALT:        
  Left Alt.

  AltL.

:LEFT_SHIFT:      
  Left Shift.

  ShiftL.

:RIGHT_ALT:       
  Right Alt.

  AltR.

:RIGHT_CTRL:      
  Right Ctrl.

  CtrlR.

:RIGHT_SHIFT:     
  Right Shift.

  ShiftR.

======================================================================

:OSKEY:           
  OS Key.

  Cmd.

:APP:             
  Application.

  App.

:GRLESS:          
  Grless.

:ESC:             
  Esc.

:TAB:             
  Tab.

:RET:             
  Return.

  Enter.

:SPACE:           
  Spacebar.

  Space.

:LINE_FEED:       
  Line Feed.

:BACK_SPACE:      
  Backspace.

  BkSpace.

:DEL:             
  Delete.

  Del.

:SEMI_COLON:      
  ;.

:PERIOD:          
:COMMA:           
  ,.

:QUOTE:           
  ".

:ACCENT_GRAVE:    
  `.

:MINUS:           
  -.

:PLUS:            
  +.

:SLASH:           
  /.

:BACK_SLASH:      
  \.

:EQUAL:           
  =.

:LEFT_BRACKET:    
  [.

:RIGHT_BRACKET:   
  ].

:LEFT_ARROW:      
  Left Arrow.

  ←.

:DOWN_ARROW:      
  Down Arrow.

  ↓.

:RIGHT_ARROW:     
  Right Arrow.

  →.

:UP_ARROW:        
  Up Arrow.

  ↑.

:NUMPAD_2:        
  Numpad 2.

  Pad2.

:NUMPAD_4:        
  Numpad 4.

  Pad4.

:NUMPAD_6:        
  Numpad 6.

  Pad6.

:NUMPAD_8:        
  Numpad 8.

  Pad8.

:NUMPAD_1:        
  Numpad 1.

  Pad1.

:NUMPAD_3:        
  Numpad 3.

  Pad3.

:NUMPAD_5:        
  Numpad 5.

  Pad5.

:NUMPAD_7:        
  Numpad 7.

  Pad7.

:NUMPAD_9:        
  Numpad 9.

  Pad9.

:NUMPAD_PERIOD:   
  Numpad ..

  Pad..

:NUMPAD_SLASH:    
  Numpad /.

  Pad/.

:NUMPAD_ASTERIX:  
  Numpad *.

  Pad*.

:NUMPAD_0:        
  Numpad 0.

  Pad0.

:NUMPAD_MINUS:    
  Numpad -.

  Pad-.

:NUMPAD_ENTER:    
  Numpad Enter.

  PadEnter.

:NUMPAD_PLUS:     
  Numpad +.

  Pad+.

:F1:              
  F1.

:F2:              
  F2.

:F3:              
  F3.

:F4:              
  F4.

:F5:              
  F5.

:F6:              
  F6.

:F7:              
  F7.

:F8:              
  F8.

:F9:              
  F9.

:F10:             
  F10.

:F11:             
  F11.

:F12:             
  F12.

:F13:             
  F13.

:F14:             
  F14.

:F15:             
  F15.

:F16:             
  F16.

:F17:             
  F17.

:F18:             
  F18.

:F19:             
  F19.

:F20:             
  F20.

:F21:             
  F21.

:F22:             
  F22.

:F23:             
  F23.

:F24:             
  F24.

:PAUSE:           
  Pause.

:INSERT:          
  Insert.

  Ins.

:HOME:            
  Home.

:PAGE_UP:         
  Page Up.

  PgUp.

:PAGE_DOWN:       
  Page Down.

  PgDown.

:END:             
  End.

======================================================================

:MEDIA_PLAY:      
  Media Play/Pause.

  ⏯.

:MEDIA_STOP:      
  Media Stop.

  ⏹.

:MEDIA_FIRST:     
  Media First.

  ⏮.

:MEDIA_LAST:      
  Media Last.

  ⏭.

======================================================================

:TEXTINPUT:       
  Text Input.

  TxtIn.

======================================================================

:WINDOW_DEACTIVATE:
  Window Deactivate.

:TIMER:           
  Timer.

  Tmr.

:TIMER0:          
  Timer 0.

  Tmr0.

:TIMER1:          
  Timer 1.

  Tmr1.

:TIMER2:          
  Timer 2.

  Tmr2.

:TIMER_JOBS:      
  Timer Jobs.

  TmrJob.

:TIMER_AUTOSAVE:  
  Timer Autosave.

  TmrSave.

:TIMER_REPORT:    
  Timer Report.

  TmrReport.

:TIMERREGION:     
  Timer Region.

  TmrReg.

======================================================================

:NDOF_MOTION:     
  NDOF Motion.

  NdofMov.

:NDOF_BUTTON_MENU:
  NDOF Menu.

  NdofMenu.

:NDOF_BUTTON_FIT: 
  NDOF Fit.

  NdofFit.

:NDOF_BUTTON_TOP: 
  NDOF Top.

  Ndof↑.

:NDOF_BUTTON_BOTTOM:
  NDOF Bottom.

  Ndof↓.

:NDOF_BUTTON_LEFT:
  NDOF Left.

  Ndof←.

:NDOF_BUTTON_RIGHT:
  NDOF Right.

  Ndof→.

:NDOF_BUTTON_FRONT:
  NDOF Front.

  NdofFront.

:NDOF_BUTTON_BACK:
  NDOF Back.

  NdofBack.

:NDOF_BUTTON_ISO1:
  NDOF Isometric 1.

  NdofIso1.

:NDOF_BUTTON_ISO2:
  NDOF Isometric 2.

  NdofIso2.

:NDOF_BUTTON_ROLL_CW:
  NDOF Roll CW.

  NdofRCW.

:NDOF_BUTTON_ROLL_CCW:
  NDOF Roll CCW.

  NdofRCCW.

:NDOF_BUTTON_SPIN_CW:
  NDOF Spin CW.

  NdofSCW.

:NDOF_BUTTON_SPIN_CCW:
  NDOF Spin CCW.

  NdofSCCW.

:NDOF_BUTTON_TILT_CW:
  NDOF Tilt CW.

  NdofTCW.

:NDOF_BUTTON_TILT_CCW:
  NDOF Tilt CCW.

  NdofTCCW.

:NDOF_BUTTON_ROTATE:
  NDOF Rotate.

  NdofRot.

:NDOF_BUTTON_PANZOOM:
  NDOF Pan/Zoom.

  NdofPanZoom.

:NDOF_BUTTON_DOMINANT:
  NDOF Dominant.

  NdofDom.

:NDOF_BUTTON_PLUS:
  NDOF Plus.

  Ndof+.

:NDOF_BUTTON_MINUS:
  NDOF Minus.

  Ndof-.

:NDOF_BUTTON_V1:  
  NDOF View 1.

:NDOF_BUTTON_V2:  
  NDOF View 2.

:NDOF_BUTTON_V3:  
  NDOF View 3.

:NDOF_BUTTON_1:   
  NDOF Button 1.

  NdofB1.

:NDOF_BUTTON_2:   
  NDOF Button 2.

  NdofB2.

:NDOF_BUTTON_3:   
  NDOF Button 3.

  NdofB3.

:NDOF_BUTTON_4:   
  NDOF Button 4.

  NdofB4.

:NDOF_BUTTON_5:   
  NDOF Button 5.

  NdofB5.

:NDOF_BUTTON_6:   
  NDOF Button 6.

  NdofB6.

:NDOF_BUTTON_7:   
  NDOF Button 7.

  NdofB7.

:NDOF_BUTTON_8:   
  NDOF Button 8.

  NdofB8.

:NDOF_BUTTON_9:   
  NDOF Button 9.

  NdofB9.

:NDOF_BUTTON_10:  
  NDOF Button 10.

  NdofB10.

:NDOF_BUTTON_A:   
  NDOF Button A.

  NdofBA.

:NDOF_BUTTON_B:   
  NDOF Button B.

  NdofBB.

:NDOF_BUTTON_C:   
  NDOF Button C.

  NdofBC.

:ACTIONZONE_AREA: 
  ActionZone Area.

  AZone Area.

:ACTIONZONE_REGION:
  ActionZone Region.

  AZone Region.

:ACTIONZONE_FULLSCREEN:
  ActionZone Fullscreen.

  AZone FullScr.

:XR_ACTION:       
  XR Action.

"""

import typing



"""


Space File Browse Mode Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:FILES:           
  File Browser.

:ASSETS:          
  Asset Browser.

.. _rna-enum-space-file-browse-mode-items:

"""

import typing



"""


Modifier Triangulate Quad Method Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:BEAUTY:          
  Beauty.

  Split the quads in nice triangles, slower method.

:FIXED:           
  Fixed.

  Split the quads on the first and third vertices.

:FIXED_ALTERNATE: 
  Fixed Alternate.

  Split the quads on the 2nd and 4th vertices.

:SHORTEST_DIAGONAL:
  Shortest Diagonal.

  Split the quads along their shortest diagonal.

:LONGEST_DIAGONAL:
  Longest Diagonal.

  Split the quads along their longest diagonal.

.. _rna-enum-modifier-triangulate-quad-method-items:

"""

import typing



"""


Extra Utilities (bpy_extras)
****************************

Utility modules associated with the bpy module.

"""

from . import view3d_utils

from . import object_utils

from . import node_utils

from . import mesh_utils

from . import keyconfig_utils

from . import io_utils

from . import image_utils

from . import id_map_utils

from . import asset_utils

from . import anim_utils

import typing



"""


Sculpt Curves Operators
***********************

:func:`brush_stroke`

:func:`min_distance_edit`

:func:`select_grow`

:func:`select_random`

"""

import typing

def brush_stroke(stroke: typing.Union[typing.Sequence[OperatorStrokeElement], typing.Mapping[str, OperatorStrokeElement], bpy.types.bpy_prop_collection] = None, mode: str = 'NORMAL') -> None:

  """

  Sculpt curves using a brush

  """

  ...

def min_distance_edit() -> None:

  """

  Change the minimum distance used by the density brush

  """

  ...

def select_grow(distance: float = 0.1) -> None:

  """

  Select curves which are close to curves that are selected already

  """

  ...

def select_random(seed: int = 0, partial: bool = False, probability: float = 0.5, min: float = 0.0, constant_per_curve: bool = True) -> None:

  """

  Randomizes existing selection or create new random selection

  """

  ...



"""


Brush Gpencil Vertex Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:DRAW:            
  Draw.

  Paint a color on stroke points.

:BLUR:            
  Blur.

  Smooth out the colors of adjacent stroke points.

:AVERAGE:         
  Average.

  Smooth out colors with the average color under the brush.

:SMEAR:           
  Smear.

  Smudge colors by grabbing and dragging them.

:REPLACE:         
  Replace.

  Replace the color of stroke points that already have a color applied.

.. _rna-enum-brush-gpencil-vertex-types-items:

"""

import typing



"""


Node Boolean Math Items
^^^^^^^^^^^^^^^^^^^^^^^

:AND:             
  And.

  True when both inputs are true.

:OR:              
  Or.

  True when at least one input is true.

:NOT:             
  Not.

  Opposite of the input.

.. _rna-enum-node-boolean-math-items:

======================================================================

:NAND:            
  Not And.

  True when at least one input is false.

:NOR:             
  Nor.

  True when both inputs are false.

:XNOR:            
  Equal.

  True when both inputs are equal (exclusive nor).

:XOR:             
  Not Equal.

  True when both inputs are different (exclusive or).

======================================================================

:IMPLY:           
  Imply.

  True unless the first input is true and the second is false.

:NIMPLY:          
  Subtract.

  True when the first input is true and the second is false (not imply).

"""

import typing



"""


Node Combsep Color Items
^^^^^^^^^^^^^^^^^^^^^^^^

:RGB:             
  RGB.

  Use RGB color processing.

:HSV:             
  HSV.

  Use HSV color processing.

:HSL:             
  HSL.

  Use HSL color processing.

.. _rna-enum-node-combsep-color-items:

"""

import typing



"""


Interpolation Utilities (mathutils.interpolate)
***********************************************

The Blender interpolate module

:func:`poly_3d_calc`

"""

import typing

def poly_3d_calc(veclist: typing.Any, pt: typing.Any) -> None:

  """

  Calculate barycentric weights for a point on a polygon.

  """

  ...



"""


Context Mode Items
^^^^^^^^^^^^^^^^^^

:EDIT_MESH:       
  Mesh Edit.

:EDIT_CURVE:      
  Curve Edit.

:EDIT_CURVES:     
  Curves Edit.

:EDIT_SURFACE:    
  Surface Edit.

:EDIT_TEXT:       
  Text Edit.

:EDIT_ARMATURE:   
  Armature Edit.

:EDIT_METABALL:   
  Metaball Edit.

:EDIT_LATTICE:    
  Lattice Edit.

:EDIT_GREASE_PENCIL:
  Grease Pencil Edit.

:EDIT_POINT_CLOUD:
  Point Cloud Edit.

:POSE:            
  Pose.

:SCULPT:          
  Sculpt.

:PAINT_WEIGHT:    
  Weight Paint.

:PAINT_VERTEX:    
  Vertex Paint.

:PAINT_TEXTURE:   
  Texture Paint.

:PARTICLE:        
  Particle.

:OBJECT:          
  Object.

:PAINT_GPENCIL:   
  Grease Pencil Paint.

:EDIT_GPENCIL:    
  Grease Pencil Edit.

:SCULPT_GPENCIL:  
  Grease Pencil Sculpt.

:WEIGHT_GPENCIL:  
  Grease Pencil Weight Paint.

:VERTEX_GPENCIL:  
  Grease Pencil Vertex Paint.

:SCULPT_CURVES:   
  Curves Sculpt.

:PAINT_GREASE_PENCIL:
  Grease Pencil Paint.

.. _rna-enum-context-mode-items:

"""

import typing



"""


Brush Operators
***************

:func:`add`

:func:`add_gpencil`

:func:`curve_preset`

:func:`reset`

:func:`scale_size`

:func:`sculpt_curves_falloff_preset`

:func:`stencil_control`

:func:`stencil_fit_image_aspect`

:func:`stencil_reset_transform`

"""

import typing

def add() -> None:

  """

  Add brush by mode type

  """

  ...

def add_gpencil() -> None:

  """

  Add brush for Grease Pencil

  """

  ...

def curve_preset(shape: str = 'SMOOTH') -> None:

  """

  Set brush shape

  """

  ...

def reset() -> None:

  """

  Return brush to defaults based on current tool

  """

  ...

def scale_size(scalar: float = 1.0) -> None:

  """

  Change brush size by a scalar

  """

  ...

def sculpt_curves_falloff_preset(shape: str = 'SMOOTH') -> None:

  """

  Set Curve Falloff Preset

  """

  ...

def stencil_control(mode: str = 'TRANSLATION', texmode: str = 'PRIMARY') -> None:

  """

  Control the stencil brush

  """

  ...

def stencil_fit_image_aspect(use_repeat: bool = True, use_scale: bool = True, mask: bool = False) -> None:

  """

  When using an image texture, adjust the stencil size to fit the image aspect ratio

  """

  ...

def stencil_reset_transform(mask: bool = False) -> None:

  """

  Reset the stencil transformation to the default

  """

  ...



"""


Mask Operators
**************

:func:`add_feather_vertex`

:func:`add_feather_vertex_slide`

:func:`add_vertex`

:func:`add_vertex_slide`

:func:`copy_splines`

:func:`cyclic_toggle`

:func:`delete`

:func:`duplicate`

:func:`duplicate_move`

:func:`feather_weight_clear`

:func:`handle_type_set`

:func:`hide_view_clear`

:func:`hide_view_set`

:func:`layer_move`

:func:`layer_new`

:func:`layer_remove`

:func:`new`

:func:`normals_make_consistent`

:func:`parent_clear`

:func:`parent_set`

:func:`paste_splines`

:func:`primitive_circle_add`

:func:`primitive_square_add`

:func:`select`

:func:`select_all`

:func:`select_box`

:func:`select_circle`

:func:`select_lasso`

:func:`select_less`

:func:`select_linked`

:func:`select_linked_pick`

:func:`select_more`

:func:`shape_key_clear`

:func:`shape_key_feather_reset`

:func:`shape_key_insert`

:func:`shape_key_rekey`

:func:`slide_point`

:func:`slide_spline_curvature`

:func:`switch_direction`

"""

import typing

import mathutils

def add_feather_vertex(location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Add vertex to feather

  """

  ...

def add_feather_vertex_slide(MASK_OT_add_feather_vertex: MASK_OT_add_feather_vertex = None, MASK_OT_slide_point: MASK_OT_slide_point = None) -> None:

  """

  Add new vertex to feather and slide it

  """

  ...

def add_vertex(location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Add vertex to active spline

  """

  ...

def add_vertex_slide(MASK_OT_add_vertex: MASK_OT_add_vertex = None, MASK_OT_slide_point: MASK_OT_slide_point = None) -> None:

  """

  Add new vertex and slide it

  """

  ...

def copy_splines() -> None:

  """

  Copy the selected splines to the internal clipboard

  """

  ...

def cyclic_toggle() -> None:

  """

  Toggle cyclic for selected splines

  """

  ...

def delete(confirm: bool = True) -> None:

  """

  Delete selected control points or splines

  """

  ...

def duplicate() -> None:

  """

  Duplicate selected control points and segments between them

  """

  ...

def duplicate_move(MASK_OT_duplicate: MASK_OT_duplicate = None, TRANSFORM_OT_translate: TRANSFORM_OT_translate = None) -> None:

  """

  Duplicate mask and move

  """

  ...

def feather_weight_clear() -> None:

  """

  Reset the feather weight to zero

  """

  ...

def handle_type_set(type: str = 'AUTO') -> None:

  """

  Set type of handles for selected control points

  """

  ...

def hide_view_clear(select: bool = True) -> None:

  """

  Reveal temporarily hidden mask layers

  """

  ...

def hide_view_set(unselected: bool = False) -> None:

  """

  Temporarily hide mask layers

  """

  ...

def layer_move(direction: str = 'UP') -> None:

  """

  Move the active layer up/down in the list

  """

  ...

def layer_new(name: str = '') -> None:

  """

  Add new mask layer for masking

  """

  ...

def layer_remove() -> None:

  """

  Remove mask layer

  """

  ...

def new(name: str = '') -> None:

  """

  Create new mask

  """

  ...

def normals_make_consistent() -> None:

  """

  Recalculate the direction of selected handles

  """

  ...

def parent_clear() -> None:

  """

  Clear the mask's parenting

  """

  ...

def parent_set() -> None:

  """

  Set the mask's parenting

  """

  ...

def paste_splines() -> None:

  """

  Paste splines from the internal clipboard

  """

  ...

def primitive_circle_add(size: float = 100.0, location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Add new circle-shaped spline

  """

  ...

def primitive_square_add(size: float = 100.0, location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Add new square-shaped spline

  """

  ...

def select(extend: bool = False, deselect: bool = False, toggle: bool = False, deselect_all: bool = False, select_passthrough: bool = False, location: mathutils.Vector = (0.0, 0.0)) -> None:

  """

  Select spline points

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  Change selection of all curve points

  """

  ...

def select_box(xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Select curve points using box selection

  """

  ...

def select_circle(x: int = 0, y: int = 0, radius: int = 25, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Select curve points using circle selection

  """

  ...

def select_lasso(path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None, mode: str = 'SET') -> None:

  """

  Select curve points using lasso selection

  """

  ...

def select_less() -> None:

  """

  Deselect spline points at the boundary of each selection region

  """

  ...

def select_linked() -> None:

  """

  Select all curve points linked to already selected ones

  """

  ...

def select_linked_pick(deselect: bool = False) -> None:

  """

  (De)select all points linked to the curve under the mouse cursor

  """

  ...

def select_more() -> None:

  """

  Select more spline points connected to initial selection

  """

  ...

def shape_key_clear() -> None:

  """

  Remove mask shape keyframe for active mask layer at the current frame

  """

  ...

def shape_key_feather_reset() -> None:

  """

  Reset feather weights on all selected points animation values

  """

  ...

def shape_key_insert() -> None:

  """

  Insert mask shape keyframe for active mask layer at the current frame

  """

  ...

def shape_key_rekey(location: bool = True, feather: bool = True) -> None:

  """

  Recalculate animation data on selected points for frames selected in the dopesheet

  """

  ...

def slide_point(slide_feather: bool = False, is_new_point: bool = False) -> None:

  """

  Slide control points

  """

  ...

def slide_spline_curvature() -> None:

  """

  Slide a point on the spline to define its curvature

  """

  ...

def switch_direction() -> None:

  """

  Switch direction of selected splines

  """

  ...



"""


Action Operators
****************

:func:`clean`

:func:`clickselect`

:func:`copy`

:func:`delete`

:func:`duplicate`

:func:`duplicate_move`

:func:`easing_type`

:func:`extrapolation_type`

:func:`frame_jump`

:func:`handle_type`

:func:`interpolation_type`

:func:`keyframe_insert`

:func:`keyframe_type`

:func:`layer_next`

:func:`layer_prev`

:func:`markers_make_local`

:func:`mirror`

:func:`new`

:func:`paste`

:func:`previewrange_set`

:func:`push_down`

:func:`sample`

:func:`select_all`

:func:`select_box`

:func:`select_circle`

:func:`select_column`

:func:`select_lasso`

:func:`select_leftright`

:func:`select_less`

:func:`select_linked`

:func:`select_more`

:func:`snap`

:func:`stash`

:func:`stash_and_create`

:func:`unlink`

:func:`view_all`

:func:`view_frame`

:func:`view_selected`

"""

import typing

def clean(threshold: float = 0.001, channels: bool = False) -> None:

  """

  Simplify F-Curves by removing closely spaced keyframes

  """

  ...

def clickselect(wait_to_deselect_others: bool = False, mouse_x: int = 0, mouse_y: int = 0, extend: bool = False, deselect_all: bool = False, column: bool = False, channel: bool = False) -> None:

  """

  Select keyframes by clicking on them

  """

  ...

def copy() -> None:

  """

  Copy selected keyframes to the internal clipboard

  """

  ...

def delete(confirm: bool = True) -> None:

  """

  Remove all selected keyframes

  """

  ...

def duplicate() -> None:

  """

  Make a copy of all selected keyframes

  """

  ...

def duplicate_move(ACTION_OT_duplicate: ACTION_OT_duplicate = None, TRANSFORM_OT_transform: TRANSFORM_OT_transform = None) -> None:

  """

  Make a copy of all selected keyframes and move them

  """

  ...

def easing_type(type: str = 'AUTO') -> None:

  """

  Set easing type for the F-Curve segments starting from the selected keyframes

  """

  ...

def extrapolation_type(type: str = 'CONSTANT') -> None:

  """

  Set extrapolation mode for selected F-Curves

  """

  ...

def frame_jump() -> None:

  """

  Set the current frame to the average frame value of selected keyframes

  """

  ...

def handle_type(type: str = 'FREE') -> None:

  """

  Set type of handle for selected keyframes

  """

  ...

def interpolation_type(type: str = 'CONSTANT') -> None:

  """

  Set interpolation mode for the F-Curve segments starting from the selected keyframes

  """

  ...

def keyframe_insert(type: str = 'ALL') -> None:

  """

  Insert keyframes for the specified channels

  """

  ...

def keyframe_type(type: str = 'KEYFRAME') -> None:

  """

  Set type of keyframe for the selected keyframes

  """

  ...

def layer_next() -> None:

  """

  Switch to editing action in animation layer above the current action in the NLA Stack

  """

  ...

def layer_prev() -> None:

  """

  Switch to editing action in animation layer below the current action in the NLA Stack

  """

  ...

def markers_make_local() -> None:

  """

  Move selected scene markers to the active Action as local 'pose' markers

  """

  ...

def mirror(type: str = 'CFRA') -> None:

  """

  Flip selected keyframes over the selected mirror line

  """

  ...

def new() -> None:

  """

  Create new action

  """

  ...

def paste(offset: str = 'START', merge: str = 'MIX', flipped: bool = False) -> None:

  """

  Paste keyframes from the internal clipboard for the selected channels, starting on the current frame

  """

  ...

def previewrange_set() -> None:

  """

  Set Preview Range based on extents of selected Keyframes

  """

  ...

def push_down() -> None:

  """

  Push action down on to the NLA stack as a new strip

  """

  ...

def sample() -> None:

  """

  Add keyframes on every frame between the selected keyframes

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  Toggle selection of all keyframes

  """

  ...

def select_box(axis_range: bool = False, xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, mode: str = 'SET', tweak: bool = False) -> None:

  """

  Select all keyframes within the specified region

  """

  ...

def select_circle(x: int = 0, y: int = 0, radius: int = 25, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Select keyframe points using circle selection

  """

  ...

def select_column(mode: str = 'KEYS') -> None:

  """

  Select all keyframes on the specified frame(s)

  """

  ...

def select_lasso(path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None, mode: str = 'SET') -> None:

  """

  Select keyframe points using lasso selection

  """

  ...

def select_leftright(mode: str = 'CHECK', extend: bool = False) -> None:

  """

  Select keyframes to the left or the right of the current frame

  """

  ...

def select_less() -> None:

  """

  Deselect keyframes on ends of selection islands

  """

  ...

def select_linked() -> None:

  """

  Select keyframes occurring in the same F-Curves as selected ones

  """

  ...

def select_more() -> None:

  """

  Select keyframes beside already selected ones

  """

  ...

def snap(type: str = 'CFRA') -> None:

  """

  Snap selected keyframes to the times specified

  """

  ...

def stash(create_new: bool = True) -> None:

  """

  Store this action in the NLA stack as a non-contributing strip for later use

  """

  ...

def stash_and_create() -> None:

  """

  Store this action in the NLA stack as a non-contributing strip for later use, and create a new action

  """

  ...

def unlink(force_delete: bool = False) -> None:

  """

  Unlink this action from the active action slot (and/or exit Tweak Mode)

  """

  ...

def view_all() -> None:

  """

  Reset viewable area to show full keyframe range

  """

  ...

def view_frame() -> None:

  """

  Move the view to the current frame

  """

  ...

def view_selected() -> None:

  """

  Reset viewable area to show selected keyframes range

  """

  ...



"""


Geometry Component Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:MESH:            
  Mesh.

  Mesh component containing point, corner, edge and face data.

:POINTCLOUD:      
  Point Cloud.

  Point cloud component containing only point data.

:CURVE:           
  Curve.

  Curve component containing spline and control point data.

:INSTANCES:       
  Instances.

  Instances of objects or collections.

.. _rna-enum-geometry-component-type-items:

"""

import typing



"""


Bake Save Mode Items
^^^^^^^^^^^^^^^^^^^^

:INTERNAL:        
  Internal.

  Save the baking map in an internal image data-block.

:EXTERNAL:        
  External.

  Save the baking map in an external file.

.. _rna-enum-bake-save-mode-items:

"""

import typing



"""


Attribute Domain Point Face Curve Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:POINT:           
  Point.

  Attribute on point.

:FACE:            
  Face.

  Attribute on mesh faces.

:CURVE:           
  Spline.

  Attribute on spline.

.. _rna-enum-attribute-domain-point-face-curve-items:

"""

import typing



"""


Brush Gpencil Sculpt Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:SMOOTH:          
  Smooth.

  Smooth stroke points.

:THICKNESS:       
  Thickness.

  Adjust thickness of strokes.

:STRENGTH:        
  Strength.

  Adjust color strength of strokes.

:RANDOMIZE:       
  Randomize.

  Introduce jitter/randomness into strokes.

:GRAB:            
  Grab.

  Translate the set of points initially within the brush circle.

:PUSH:            
  Push.

  Move points out of the way, as if combing them.

:TWIST:           
  Twist.

  Rotate points around the midpoint of the brush.

:PINCH:           
  Pinch.

  Pull points towards the midpoint of the brush.

:CLONE:           
  Clone.

  Paste copies of the strokes stored on the internal clipboard.

.. _rna-enum-brush-gpencil-sculpt-types-items:

"""

import typing



"""


Preferences Operators
*********************

:func:`addon_disable`

:func:`addon_enable`

:func:`addon_expand`

:func:`addon_install`

:func:`addon_refresh`

:func:`addon_remove`

:func:`addon_show`

:func:`app_template_install`

:func:`asset_library_add`

:func:`asset_library_remove`

:func:`associate_blend`

:func:`autoexec_path_add`

:func:`autoexec_path_remove`

:func:`copy_prev`

:func:`extension_repo_add`

:func:`extension_repo_remove`

:func:`keyconfig_activate`

:func:`keyconfig_export`

:func:`keyconfig_import`

:func:`keyconfig_remove`

:func:`keyconfig_test`

:func:`keyitem_add`

:func:`keyitem_remove`

:func:`keyitem_restore`

:func:`keymap_restore`

:func:`reset_default_theme`

:func:`script_directory_add`

:func:`script_directory_remove`

:func:`studiolight_copy_settings`

:func:`studiolight_install`

:func:`studiolight_new`

:func:`studiolight_show`

:func:`studiolight_uninstall`

:func:`theme_install`

:func:`unassociate_blend`

"""

import typing

def addon_disable(module: str = '') -> None:

  """

  Disable an add-on

  """

  ...

def addon_enable(module: str = '') -> None:

  """

  Enable an add-on

  """

  ...

def addon_expand(module: str = '') -> None:

  """

  Display information and preferences for this add-on

  """

  ...

def addon_install(overwrite: bool = True, target: str = '', filepath: str = '', filter_folder: bool = True, filter_python: bool = True, filter_glob: str = '*args.py;*args.zip') -> None:

  """

  Install an add-on

  """

  ...

def addon_refresh() -> None:

  """

  Scan add-on directories for new modules

  """

  ...

def addon_remove(module: str = '') -> None:

  """

  Delete the add-on from the file system

  """

  ...

def addon_show(module: str = '') -> None:

  """

  Show add-on preferences

  """

  ...

def app_template_install(overwrite: bool = True, filepath: str = '', filter_folder: bool = True, filter_glob: str = '*args.zip') -> None:

  """

  Install an application template

  """

  ...

def asset_library_add(directory: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Add a directory to be used by the Asset Browser as source of assets

  """

  ...

def asset_library_remove(index: int = 0) -> None:

  """

  Remove a path to a .blend file, so the Asset Browser will not attempt to show it anymore

  """

  ...

def associate_blend() -> None:

  """

  Use this installation for .blend files and to display thumbnails

  """

  ...

def autoexec_path_add() -> None:

  """

  Add path to exclude from auto-execution

  """

  ...

def autoexec_path_remove(index: int = 0) -> None:

  """

  Remove path to exclude from auto-execution

  """

  ...

def copy_prev() -> None:

  """

  Copy settings from previous version

  """

  ...

def extension_repo_add(directory: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Add a directory to be used as a local extension repository

  """

  ...

def extension_repo_remove(index: int = 0) -> None:

  """

  Remove an extension repository

  """

  ...

def keyconfig_activate(filepath: str = '') -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/>`_.

  """

  ...

def keyconfig_export(all: bool = False, filepath: str = '', filter_folder: bool = True, filter_text: bool = True, filter_python: bool = True) -> None:

  """

  Export key configuration to a Python script

  """

  ...

def keyconfig_import(filepath: str = 'keymap.py', filter_folder: bool = True, filter_text: bool = True, filter_python: bool = True, keep_original: bool = True) -> None:

  """

  Import key configuration from a Python script

  """

  ...

def keyconfig_remove() -> None:

  """

  Remove key config

  """

  ...

def keyconfig_test() -> None:

  """

  Test key configuration for conflicts

  """

  ...

def keyitem_add() -> None:

  """

  Add key map item

  """

  ...

def keyitem_remove(item_id: int = 0) -> None:

  """

  Remove key map item

  """

  ...

def keyitem_restore(item_id: int = 0) -> None:

  """

  Restore key map item

  """

  ...

def keymap_restore(all: bool = False) -> None:

  """

  Restore key map(s)

  """

  ...

def reset_default_theme() -> None:

  """

  Reset to the default theme colors

  """

  ...

def script_directory_add(directory: str = '', filter_folder: bool = True) -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/>`_.

  """

  ...

def script_directory_remove(index: int = 0) -> None:

  """

  Undocumented, consider `contributing <https://developer.blender.org/>`_.

  """

  ...

def studiolight_copy_settings(index: int = 0) -> None:

  """

  Copy Studio Light settings to the Studio Light editor

  """

  ...

def studiolight_install(files: typing.Union[typing.Sequence[OperatorFileListElement], typing.Mapping[str, OperatorFileListElement], bpy.types.bpy_prop_collection] = None, directory: str = '', filter_folder: bool = True, filter_glob: str = '*args.png;*args.jpg;*args.hdr;*args.exr', type: str = 'MATCAP') -> None:

  """

  Install a user defined light

  """

  ...

def studiolight_new(filename: str = 'StudioLight') -> None:

  """

  Save custom studio light from the studio light editor settings

  """

  ...

def studiolight_show() -> None:

  """

  Show light preferences

  """

  ...

def studiolight_uninstall(index: int = 0) -> None:

  """

  Delete Studio Light

  """

  ...

def theme_install(overwrite: bool = True, filepath: str = '', filter_folder: bool = True, filter_glob: str = '*args.xml') -> None:

  """

  Load and apply a Blender XML theme file

  """

  ...

def unassociate_blend() -> None:

  """

  Remove this installation's associations with .blend files

  """

  ...



"""


Window Cursor Items
^^^^^^^^^^^^^^^^^^^

:DEFAULT:         
  Default.

:NONE:            
  None.

:WAIT:            
  Wait.

:CROSSHAIR:       
  Crosshair.

:MOVE_X:          
  Move-X.

:MOVE_Y:          
  Move-Y.

:KNIFE:           
  Knife.

:TEXT:            
  Text.

:PAINT_BRUSH:     
  Paint Brush.

:PAINT_CROSS:     
  Paint Cross.

:DOT:             
  Dot Cursor.

:ERASER:          
  Eraser.

:HAND:            
  Hand.

:SCROLL_X:        
  Scroll-X.

:SCROLL_Y:        
  Scroll-Y.

:SCROLL_XY:       
  Scroll-XY.

:EYEDROPPER:      
  Eyedropper.

:PICK_AREA:       
  Pick Area.

:STOP:            
  Stop.

:COPY:            
  Copy.

:CROSS:           
  Cross.

:MUTE:            
  Mute.

:ZOOM_IN:         
  Zoom In.

:ZOOM_OUT:        
  Zoom Out.

.. _rna-enum-window-cursor-items:

"""

import typing



"""


Gpencil Operators
*****************

:func:`active_frame_delete`

:func:`active_frames_delete_all`

:func:`annotate`

:func:`annotation_active_frame_delete`

:func:`annotation_add`

:func:`bake_grease_pencil_animation`

:func:`bake_mesh_animation`

:func:`blank_frame_add`

:func:`brush_reset`

:func:`brush_reset_all`

:func:`convert`

:func:`convert_old_files`

:func:`copy`

:func:`data_unlink`

:func:`delete`

:func:`dissolve`

:func:`draw`

:func:`duplicate`

:func:`duplicate_move`

:func:`editmode_toggle`

:func:`extract_palette_vertex`

:func:`extrude`

:func:`extrude_move`

:func:`fill`

:func:`frame_clean_duplicate`

:func:`frame_clean_fill`

:func:`frame_clean_loose`

:func:`frame_duplicate`

:func:`generate_weights`

:func:`guide_rotate`

:func:`hide`

:func:`image_to_grease_pencil`

:func:`interpolate`

:func:`interpolate_reverse`

:func:`interpolate_sequence`

:func:`layer_active`

:func:`layer_add`

:func:`layer_annotation_add`

:func:`layer_annotation_move`

:func:`layer_annotation_remove`

:func:`layer_change`

:func:`layer_duplicate`

:func:`layer_duplicate_object`

:func:`layer_isolate`

:func:`layer_mask_add`

:func:`layer_mask_move`

:func:`layer_mask_remove`

:func:`layer_merge`

:func:`layer_move`

:func:`layer_remove`

:func:`lock_all`

:func:`lock_layer`

:func:`material_hide`

:func:`material_isolate`

:func:`material_lock_all`

:func:`material_lock_unused`

:func:`material_reveal`

:func:`material_select`

:func:`material_set`

:func:`material_to_vertex_color`

:func:`material_unlock_all`

:func:`materials_copy_to_object`

:func:`move_to_layer`

:func:`paintmode_toggle`

:func:`paste`

:func:`primitive_box`

:func:`primitive_circle`

:func:`primitive_curve`

:func:`primitive_line`

:func:`primitive_polyline`

:func:`recalc_geometry`

:func:`reproject`

:func:`reset_transform_fill`

:func:`reveal`

:func:`sculpt_paint`

:func:`sculptmode_toggle`

:func:`segment_add`

:func:`segment_move`

:func:`segment_remove`

:func:`select`

:func:`select_all`

:func:`select_alternate`

:func:`select_box`

:func:`select_circle`

:func:`select_first`

:func:`select_grouped`

:func:`select_lasso`

:func:`select_last`

:func:`select_less`

:func:`select_linked`

:func:`select_more`

:func:`select_random`

:func:`select_vertex_color`

:func:`selection_opacity_toggle`

:func:`selectmode_toggle`

:func:`set_active_material`

:func:`snap_cursor_to_selected`

:func:`snap_to_cursor`

:func:`snap_to_grid`

:func:`stroke_apply_thickness`

:func:`stroke_arrange`

:func:`stroke_caps_set`

:func:`stroke_change_color`

:func:`stroke_cutter`

:func:`stroke_cyclical_set`

:func:`stroke_editcurve_set_handle_type`

:func:`stroke_enter_editcurve_mode`

:func:`stroke_flip`

:func:`stroke_join`

:func:`stroke_merge`

:func:`stroke_merge_by_distance`

:func:`stroke_merge_material`

:func:`stroke_normalize`

:func:`stroke_outline`

:func:`stroke_reset_vertex_color`

:func:`stroke_sample`

:func:`stroke_separate`

:func:`stroke_simplify`

:func:`stroke_simplify_fixed`

:func:`stroke_smooth`

:func:`stroke_split`

:func:`stroke_start_set`

:func:`stroke_subdivide`

:func:`stroke_trim`

:func:`time_segment_add`

:func:`time_segment_move`

:func:`time_segment_remove`

:func:`tint_flip`

:func:`transform_fill`

:func:`unlock_all`

:func:`vertex_color_brightness_contrast`

:func:`vertex_color_hsv`

:func:`vertex_color_invert`

:func:`vertex_color_levels`

:func:`vertex_color_set`

:func:`vertex_group_assign`

:func:`vertex_group_deselect`

:func:`vertex_group_invert`

:func:`vertex_group_normalize`

:func:`vertex_group_normalize_all`

:func:`vertex_group_remove_from`

:func:`vertex_group_select`

:func:`vertex_group_smooth`

:func:`vertex_paint`

:func:`vertexmode_toggle`

:func:`weight_paint`

:func:`weight_sample`

:func:`weight_toggle_direction`

:func:`weightmode_toggle`

"""

import typing

import mathutils

def active_frame_delete() -> None:

  """

  Delete the active frame for the active Grease Pencil Layer

  """

  ...

def active_frames_delete_all() -> None:

  """

  Delete the active frame(s) of all editable Grease Pencil layers

  """

  ...

def annotate(mode: str = 'DRAW', arrowstyle_start: str = 'NONE', arrowstyle_end: str = 'NONE', use_stabilizer: bool = False, stabilizer_factor: float = 0.75, stabilizer_radius: int = 35, stroke: typing.Union[typing.Sequence[OperatorStrokeElement], typing.Mapping[str, OperatorStrokeElement], bpy.types.bpy_prop_collection] = None, wait_for_input: bool = True) -> None:

  """

  Make annotations on the active data

  """

  ...

def annotation_active_frame_delete() -> None:

  """

  Delete the active frame for the active Annotation Layer

  """

  ...

def annotation_add() -> None:

  """

  Add new Annotation data-block

  """

  ...

def bake_grease_pencil_animation(frame_start: int = 1, frame_end: int = 250, step: int = 1, only_selected: bool = False, frame_target: int = 1, project_type: str = 'KEEP') -> None:

  """

  Bake grease pencil object transform to grease pencil keyframes

  """

  ...

def bake_mesh_animation(target: str = 'NEW', frame_start: int = 1, frame_end: int = 250, step: int = 1, thickness: int = 1, angle: float = 1.22173, offset: float = 0.001, seams: bool = False, faces: bool = True, only_selected: bool = False, frame_target: int = 1, project_type: str = 'VIEW') -> None:

  """

  Bake mesh animation to grease pencil strokes

  """

  ...

def blank_frame_add(all_layers: bool = False) -> None:

  """

  Insert a blank frame on the current frame (all subsequently existing frames, if any, are shifted right by one frame)

  """

  ...

def brush_reset() -> None:

  """

  Reset brush to default parameters

  """

  ...

def brush_reset_all() -> None:

  """

  Delete all mode brushes and recreate a default set

  """

  ...

def convert(type: str = 'PATH', bevel_depth: float = 0.0, bevel_resolution: int = 0, use_normalize_weights: bool = True, radius_multiplier: float = 1.0, use_link_strokes: bool = False, timing_mode: str = 'FULL', frame_range: int = 100, start_frame: int = 1, use_realtime: bool = False, end_frame: int = 250, gap_duration: float = 0.0, gap_randomness: float = 0.0, seed: int = 0, use_timing_data: bool = False) -> None:

  """

  Convert the active Grease Pencil layer to a new Curve Object

  """

  ...

def convert_old_files(annotation: bool = False) -> None:

  """

  Convert 2.7x grease pencil files to 2.80

  """

  ...

def copy() -> None:

  """

  Copy selected Grease Pencil points and strokes

  """

  ...

def data_unlink() -> None:

  """

  Unlink active Annotation data-block

  """

  ...

def delete(type: str = 'POINTS') -> None:

  """

  Delete selected Grease Pencil strokes, vertices, or frames

  """

  ...

def dissolve(type: str = 'POINTS') -> None:

  """

  Delete selected points without splitting strokes

  """

  ...

def draw(mode: str = 'DRAW', stroke: typing.Union[typing.Sequence[OperatorStrokeElement], typing.Mapping[str, OperatorStrokeElement], bpy.types.bpy_prop_collection] = None, wait_for_input: bool = True, disable_straight: bool = False, disable_fill: bool = False, disable_stabilizer: bool = False, guide_last_angle: float = 0.0) -> None:

  """

  Draw a new stroke in the active Grease Pencil object

  """

  ...

def duplicate() -> None:

  """

  Duplicate the selected Grease Pencil strokes

  """

  ...

def duplicate_move(GPENCIL_OT_duplicate: GPENCIL_OT_duplicate = None, TRANSFORM_OT_translate: TRANSFORM_OT_translate = None) -> None:

  """

  Make copies of the selected Grease Pencil strokes and move them

  """

  ...

def editmode_toggle(back: bool = False) -> None:

  """

  Enter/Exit edit mode for Grease Pencil strokes

  """

  ...

def extract_palette_vertex(selected: bool = False, threshold: int = 1) -> None:

  """

  Extract all colors used in Grease Pencil Vertex and create a Palette

  """

  ...

def extrude() -> None:

  """

  Extrude the selected Grease Pencil points

  """

  ...

def extrude_move(GPENCIL_OT_extrude: GPENCIL_OT_extrude = None, TRANSFORM_OT_translate: TRANSFORM_OT_translate = None) -> None:

  """

  Extrude selected points and move them

  """

  ...

def fill(on_back: bool = False) -> None:

  """

  Fill with color the shape formed by strokes

  """

  ...

def frame_clean_duplicate(type: str = 'ALL') -> None:

  """

  Remove duplicate keyframes

  """

  ...

def frame_clean_fill(mode: str = 'ACTIVE') -> None:

  """

  Remove 'no fill' boundary strokes

  """

  ...

def frame_clean_loose(limit: int = 1) -> None:

  """

  Remove loose points

  """

  ...

def frame_duplicate(mode: str = 'ACTIVE') -> None:

  """

  Make a copy of the active Grease Pencil Frame

  """

  ...

def generate_weights(mode: str = 'NAME', armature: str = 'DEFAULT', ratio: float = 0.1, decay: float = 0.8) -> None:

  """

  Generate automatic weights for armatures (requires armature modifier)

  """

  ...

def guide_rotate(increment: bool = True, angle: float = 0.0) -> None:

  """

  Rotate guide angle

  """

  ...

def hide(unselected: bool = False) -> None:

  """

  Hide selected/unselected Grease Pencil layers

  """

  ...

def image_to_grease_pencil(size: float = 0.005, mask: bool = False) -> None:

  """

  Generate a Grease Pencil Object using Image as source

  """

  ...

def interpolate(shift: float = 0.0, layers: str = 'ACTIVE', interpolate_selected_only: bool = False, exclude_breakdowns: bool = False, flip: str = 'AUTO', smooth_steps: int = 1, smooth_factor: float = 0.0, release_confirm: bool = False) -> None:

  """

  Interpolate grease pencil strokes between frames

  """

  ...

def interpolate_reverse() -> None:

  """

  Remove breakdown frames generated by interpolating between two Grease Pencil frames

  """

  ...

def interpolate_sequence(step: int = 1, layers: str = 'ACTIVE', interpolate_selected_only: bool = False, exclude_breakdowns: bool = False, flip: str = 'AUTO', smooth_steps: int = 1, smooth_factor: float = 0.0, type: str = 'LINEAR', easing: str = 'AUTO', back: float = 1.702, amplitude: float = 0.15, period: float = 0.15) -> None:

  """

  Generate 'in-betweens' to smoothly interpolate between Grease Pencil frames

  """

  ...

def layer_active(layer: int = 0) -> None:

  """

  Active Grease Pencil layer

  """

  ...

def layer_add(layer: int = 0, new_layer_name: str = '') -> None:

  """

  Add new layer or note for the active data-block

  """

  ...

def layer_annotation_add() -> None:

  """

  Add new Annotation layer or note for the active data-block

  """

  ...

def layer_annotation_move(type: str = 'UP') -> None:

  """

  Move the active Annotation layer up/down in the list

  """

  ...

def layer_annotation_remove() -> None:

  """

  Remove active Annotation layer

  """

  ...

def layer_change(layer: str = 'DEFAULT') -> None:

  """

  Change active Grease Pencil layer

  """

  ...

def layer_duplicate(mode: str = 'ALL') -> None:

  """

  Make a copy of the active Grease Pencil layer

  """

  ...

def layer_duplicate_object(mode: str = 'ALL', only_active: bool = True) -> None:

  """

  Make a copy of the active Grease Pencil layer to selected object

  """

  ...

def layer_isolate(affect_visibility: bool = False) -> None:

  """

  Toggle whether the active layer is the only one that can be edited and/or visible

  """

  ...

def layer_mask_add(name: str = '') -> None:

  """

  Add new layer as masking

  """

  ...

def layer_mask_move(type: str = 'UP') -> None:

  """

  Move the active Grease Pencil mask layer up/down in the list

  """

  ...

def layer_mask_remove() -> None:

  """

  Remove Layer Mask

  """

  ...

def layer_merge(mode: str = 'ACTIVE') -> None:

  """

  Combine Layers

  """

  ...

def layer_move(type: str = 'UP') -> None:

  """

  Move the active Grease Pencil layer up/down in the list

  """

  ...

def layer_remove() -> None:

  """

  Remove active Grease Pencil layer

  """

  ...

def lock_all() -> None:

  """

  Lock all Grease Pencil layers to prevent them from being accidentally modified

  """

  ...

def lock_layer() -> None:

  """

  Lock and hide any color not used in any layer

  """

  ...

def material_hide(unselected: bool = False) -> None:

  """

  Hide selected/unselected Grease Pencil materials

  """

  ...

def material_isolate(affect_visibility: bool = False) -> None:

  """

  Toggle whether the active material is the only one that is editable and/or visible

  """

  ...

def material_lock_all() -> None:

  """

  Lock all Grease Pencil materials to prevent them from being accidentally modified

  """

  ...

def material_lock_unused() -> None:

  """

  Lock any material not used in any selected stroke

  """

  ...

def material_reveal() -> None:

  """

  Unhide all hidden Grease Pencil materials

  """

  ...

def material_select(deselect: bool = False) -> None:

  """

  Select/Deselect all Grease Pencil strokes using current material

  """

  ...

def material_set(slot: str = 'DEFAULT') -> None:

  """

  Set active material

  """

  ...

def material_to_vertex_color(remove: bool = True, palette: bool = True, selected: bool = False, threshold: int = 3) -> None:

  """

  Replace materials in strokes with Vertex Color

  """

  ...

def material_unlock_all() -> None:

  """

  Unlock all Grease Pencil materials so that they can be edited

  """

  ...

def materials_copy_to_object(only_active: bool = True) -> None:

  """

  Append Materials of the active Grease Pencil to other object

  """

  ...

def move_to_layer(layer: int = 0, new_layer_name: str = '') -> None:

  """

  Move selected strokes to another layer

  """

  ...

def paintmode_toggle(back: bool = False) -> None:

  """

  Enter/Exit paint mode for Grease Pencil strokes

  """

  ...

def paste(type: str = 'ACTIVE', paste_back: bool = False) -> None:

  """

  Paste previously copied strokes to active layer or to original layer

  """

  ...

def primitive_box(subdivision: int = 3, edges: int = 1, type: str = 'BOX', wait_for_input: bool = True) -> None:

  """

  Create predefined grease pencil stroke box shapes

  """

  ...

def primitive_circle(subdivision: int = 94, edges: int = 1, type: str = 'CIRCLE', wait_for_input: bool = True) -> None:

  """

  Create predefined grease pencil stroke circle shapes

  """

  ...

def primitive_curve(subdivision: int = 62, edges: int = 1, type: str = 'CURVE', wait_for_input: bool = True) -> None:

  """

  Create predefined grease pencil stroke curve shapes

  """

  ...

def primitive_line(subdivision: int = 6, edges: int = 1, type: str = 'LINE', wait_for_input: bool = True) -> None:

  """

  Create predefined grease pencil stroke lines

  """

  ...

def primitive_polyline(subdivision: int = 6, edges: int = 1, type: str = 'POLYLINE', wait_for_input: bool = True) -> None:

  """

  Create predefined grease pencil stroke polylines

  """

  ...

def recalc_geometry() -> None:

  """

  Update all internal geometry data

  """

  ...

def reproject(type: str = 'VIEW', keep_original: bool = False, offset: float = 0.0) -> None:

  """

  Reproject the selected strokes from the current viewpoint as if they had been newly drawn (e.g. to fix problems from accidental 3D cursor movement or accidental viewport changes, or for matching deforming geometry)

  """

  ...

def reset_transform_fill(mode: str = 'ALL') -> None:

  """

  Reset any UV transformation and back to default values

  """

  ...

def reveal(select: bool = True) -> None:

  """

  Show all Grease Pencil layers

  """

  ...

def sculpt_paint(stroke: typing.Union[typing.Sequence[OperatorStrokeElement], typing.Mapping[str, OperatorStrokeElement], bpy.types.bpy_prop_collection] = None, wait_for_input: bool = True) -> None:

  """

  Apply tweaks to strokes by painting over the strokes

  """

  ...

def sculptmode_toggle(back: bool = False) -> None:

  """

  Enter/Exit sculpt mode for Grease Pencil strokes

  """

  ...

def segment_add(modifier: str = '') -> None:

  """

  Add a segment to the dash modifier

  """

  ...

def segment_move(modifier: str = '', type: str = 'UP') -> None:

  """

  Move the active dash segment up or down

  """

  ...

def segment_remove(modifier: str = '', index: int = 0) -> None:

  """

  Remove the active segment from the dash modifier

  """

  ...

def select(extend: bool = False, deselect: bool = False, toggle: bool = False, deselect_all: bool = False, select_passthrough: bool = False, entire_strokes: bool = False, location: typing.Tuple[int, int] = (0, 0), use_shift_extend: bool = False) -> None:

  """

  Select Grease Pencil strokes and/or stroke points

  """

  ...

def select_all(action: str = 'TOGGLE') -> None:

  """

  Change selection of all Grease Pencil strokes currently visible

  """

  ...

def select_alternate(unselect_ends: bool = False) -> None:

  """

  Select alternative points in same strokes as already selected points

  """

  ...

def select_box(xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Select Grease Pencil strokes within a rectangular region

  """

  ...

def select_circle(x: int = 0, y: int = 0, radius: int = 25, wait_for_input: bool = True, mode: str = 'SET') -> None:

  """

  Select Grease Pencil strokes using brush selection

  """

  ...

def select_first(only_selected_strokes: bool = False, extend: bool = False) -> None:

  """

  Select first point in Grease Pencil strokes

  """

  ...

def select_grouped(type: str = 'LAYER') -> None:

  """

  Select all strokes with similar characteristics

  """

  ...

def select_lasso(mode: str = 'SET', path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None) -> None:

  """

  Select Grease Pencil strokes using lasso selection

  """

  ...

def select_last(only_selected_strokes: bool = False, extend: bool = False) -> None:

  """

  Select last point in Grease Pencil strokes

  """

  ...

def select_less() -> None:

  """

  Shrink sets of selected Grease Pencil points

  """

  ...

def select_linked() -> None:

  """

  Select all points in same strokes as already selected points

  """

  ...

def select_more() -> None:

  """

  Grow sets of selected Grease Pencil points

  """

  ...

def select_random(ratio: float = 0.5, seed: int = 0, action: str = 'SELECT', unselect_ends: bool = False) -> None:

  """

  Select random points for non selected strokes

  """

  ...

def select_vertex_color(threshold: int = 0) -> None:

  """

  Select all points with similar vertex color of current selected

  """

  ...

def selection_opacity_toggle() -> None:

  """

  Hide/Unhide selected points for Grease Pencil strokes setting alpha factor

  """

  ...

def selectmode_toggle(mode: int = 0) -> None:

  """

  Set selection mode for Grease Pencil strokes

  """

  ...

def set_active_material() -> None:

  """

  Set the selected stroke material as the active material

  """

  ...

def snap_cursor_to_selected() -> None:

  """

  Snap cursor to center of selected points

  """

  ...

def snap_to_cursor(use_offset: bool = True) -> None:

  """

  Snap selected points/strokes to the cursor

  """

  ...

def snap_to_grid() -> None:

  """

  Snap selected points to the nearest grid points

  """

  ...

def stroke_apply_thickness() -> None:

  """

  Apply the thickness change of the layer to its strokes

  """

  ...

def stroke_arrange(direction: str = 'UP') -> None:

  """

  Arrange selected strokes up/down in the display order of the active layer

  """

  ...

def stroke_caps_set(type: str = 'TOGGLE') -> None:

  """

  Change stroke caps mode (rounded or flat)

  """

  ...

def stroke_change_color(material: str = '') -> None:

  """

  Move selected strokes to active material

  """

  ...

def stroke_cutter(path: typing.Union[typing.Sequence[OperatorMousePath], typing.Mapping[str, OperatorMousePath], bpy.types.bpy_prop_collection] = None, flat_caps: bool = False) -> None:

  """

  Select section and cut

  """

  ...

def stroke_cyclical_set(type: str = 'TOGGLE', geometry: bool = False) -> None:

  """

  Close or open the selected stroke adding a segment from last to first point

  """

  ...

def stroke_editcurve_set_handle_type(type: str = 'AUTOMATIC') -> None:

  """

  Set the type of an edit curve handle

  """

  ...

def stroke_enter_editcurve_mode(error_threshold: float = 0.1) -> None:

  """

  Called to transform a stroke into a curve

  """

  ...

def stroke_flip() -> None:

  """

  Change direction of the points of the selected strokes

  """

  ...

def stroke_join(type: str = 'JOIN', leave_gaps: bool = False) -> None:

  """

  Join selected strokes (optionally as new stroke)

  """

  ...

def stroke_merge(mode: str = 'STROKE', back: bool = False, additive: bool = False, cyclic: bool = False, clear_point: bool = False, clear_stroke: bool = False) -> None:

  """

  Create a new stroke with the selected stroke points

  """

  ...

def stroke_merge_by_distance(threshold: float = 0.001, use_unselected: bool = False) -> None:

  """

  Merge points by distance

  """

  ...

def stroke_merge_material(hue_threshold: float = 0.001, sat_threshold: float = 0.001, val_threshold: float = 0.001) -> None:

  """

  Replace materials in strokes merging similar

  """

  ...

def stroke_normalize(mode: str = 'THICKNESS', factor: float = 1.0, value: int = 10) -> None:

  """

  Normalize stroke attributes

  """

  ...

def stroke_outline(view_mode: str = 'VIEW', material_mode: str = 'ACTIVE', thickness: int = 1, keep: bool = True, subdivisions: int = 3, length: float = 0.0) -> None:

  """

  Convert stroke to perimeter

  """

  ...

def stroke_reset_vertex_color(mode: str = 'BOTH') -> None:

  """

  Reset vertex color for all or selected strokes

  """

  ...

def stroke_sample(length: float = 0.1, sharp_threshold: float = 0.1) -> None:

  """

  Sample stroke points to predefined segment length

  """

  ...

def stroke_separate(mode: str = 'POINT') -> None:

  """

  Separate the selected strokes or layer in a new grease pencil object

  """

  ...

def stroke_simplify(factor: float = 0.0) -> None:

  """

  Simplify selected strokes, reducing number of points

  """

  ...

def stroke_simplify_fixed(step: int = 1) -> None:

  """

  Simplify selected strokes, reducing number of points using fixed algorithm

  """

  ...

def stroke_smooth(repeat: int = 2, factor: float = 1.0, only_selected: bool = True, smooth_position: bool = True, smooth_thickness: bool = True, smooth_strength: bool = False, smooth_uv: bool = False) -> None:

  """

  Smooth selected strokes

  """

  ...

def stroke_split() -> None:

  """

  Split selected points as new stroke on same frame

  """

  ...

def stroke_start_set() -> None:

  """

  Set start point for cyclic strokes

  """

  ...

def stroke_subdivide(number_cuts: int = 1, factor: float = 0.0, repeat: int = 1, only_selected: bool = True, smooth_position: bool = True, smooth_thickness: bool = True, smooth_strength: bool = False, smooth_uv: bool = False) -> None:

  """

  Subdivide between continuous selected points of the stroke adding a point half way between them

  """

  ...

def stroke_trim() -> None:

  """

  Trim selected stroke to first loop or intersection

  """

  ...

def time_segment_add(modifier: str = '') -> None:

  """

  Add a segment to the time modifier

  """

  ...

def time_segment_move(modifier: str = '', type: str = 'UP') -> None:

  """

  Move the active time segment up or down

  """

  ...

def time_segment_remove(modifier: str = '', index: int = 0) -> None:

  """

  Remove the active segment from the time modifier

  """

  ...

def tint_flip() -> None:

  """

  Switch tint colors

  """

  ...

def transform_fill(mode: str = 'ROTATE', location: mathutils.Vector = (0.0, 0.0), rotation: float = 0.0, scale: float = 0.0, release_confirm: bool = False) -> None:

  """

  Transform grease pencil stroke fill

  """

  ...

def unlock_all() -> None:

  """

  Unlock all Grease Pencil layers so that they can be edited

  """

  ...

def vertex_color_brightness_contrast(mode: str = 'BOTH', brightness: float = 0.0, contrast: float = 0.0) -> None:

  """

  Adjust vertex color brightness/contrast

  """

  ...

def vertex_color_hsv(mode: str = 'BOTH', h: float = 0.5, s: float = 1.0, v: float = 1.0) -> None:

  """

  Adjust vertex color HSV values

  """

  ...

def vertex_color_invert(mode: str = 'BOTH') -> None:

  """

  Invert RGB values

  """

  ...

def vertex_color_levels(mode: str = 'BOTH', offset: float = 0.0, gain: float = 1.0) -> None:

  """

  Adjust levels of vertex colors

  """

  ...

def vertex_color_set(mode: str = 'BOTH', factor: float = 1.0) -> None:

  """

  Set active color to all selected vertex

  """

  ...

def vertex_group_assign() -> None:

  """

  Assign the selected vertices to the active vertex group

  """

  ...

def vertex_group_deselect() -> None:

  """

  Deselect all selected vertices assigned to the active vertex group

  """

  ...

def vertex_group_invert() -> None:

  """

  Invert weights to the active vertex group

  """

  ...

def vertex_group_normalize() -> None:

  """

  Normalize weights to the active vertex group

  """

  ...

def vertex_group_normalize_all(lock_active: bool = True) -> None:

  """

  Normalize all weights of all vertex groups, so that for each vertex, the sum of all weights is 1.0

  """

  ...

def vertex_group_remove_from() -> None:

  """

  Remove the selected vertices from active or all vertex group(s)

  """

  ...

def vertex_group_select() -> None:

  """

  Select all the vertices assigned to the active vertex group

  """

  ...

def vertex_group_smooth(factor: float = 0.5, repeat: int = 1) -> None:

  """

  Smooth weights to the active vertex group

  """

  ...

def vertex_paint(stroke: typing.Union[typing.Sequence[OperatorStrokeElement], typing.Mapping[str, OperatorStrokeElement], bpy.types.bpy_prop_collection] = None, wait_for_input: bool = True) -> None:

  """

  Paint stroke points with a color

  """

  ...

def vertexmode_toggle(back: bool = False) -> None:

  """

  Enter/Exit vertex paint mode for Grease Pencil strokes

  """

  ...

def weight_paint(stroke: typing.Union[typing.Sequence[OperatorStrokeElement], typing.Mapping[str, OperatorStrokeElement], bpy.types.bpy_prop_collection] = None, wait_for_input: bool = True) -> None:

  """

  Draw weight on stroke points

  """

  ...

def weight_sample() -> None:

  """

  Use the mouse to sample a weight in the 3D view

  """

  ...

def weight_toggle_direction() -> None:

  """

  Toggle Add/Subtract for the weight paint draw tool

  """

  ...

def weightmode_toggle(back: bool = False) -> None:

  """

  Enter/Exit weight paint mode for Grease Pencil strokes

  """

  ...



"""


Aset Library Type Items
^^^^^^^^^^^^^^^^^^^^^^^

:LOCAL:           
  Local.

:ALL:             
  All.

:ESSENTIALS:      
  Essentials.

:CUSTOM:          
  Custom.

.. _rna-enum-aset-library-type-items:

"""

import typing



"""


Clip Editor Mode Items
^^^^^^^^^^^^^^^^^^^^^^

:TRACKING:        
  Tracking.

  Show tracking and solving tools.

:MASK:            
  Mask.

  Show mask editing tools.

.. _rna-enum-clip-editor-mode-items:

"""

import typing



"""


Rigidbody Object Shape Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:BOX:             
  Box.

  Box-like shapes (i.e. cubes), including planes (i.e. ground planes).

:SPHERE:          
  Sphere.

:CAPSULE:         
  Capsule.

:CYLINDER:        
  Cylinder.

:CONE:            
  Cone.

:CONVEX_HULL:     
  Convex Hull.

  A mesh-like surface encompassing (i.e. shrinkwrap over) all vertices (best results with fewer vertices).

:MESH:            
  Mesh.

  Mesh consisting of triangles only, allowing for more detailed interactions than convex hulls.

:COMPOUND:        
  Compound Parent.

  Combines all of its direct rigid body children into one rigid object.

.. _rna-enum-rigidbody-object-shape-items:

"""

import typing



"""


bpy_extras submodule (bpy_extras.id_map_utils)
**********************************************

:func:`get_id_reference_map`

:func:`get_all_referenced_ids`

"""

import typing

def get_id_reference_map() -> None:

  """

  Return a dictionary of direct datablock references for every datablock in the blend file.

  """

  ...

def get_all_referenced_ids(id: typing.Any, ref_map: typing.Any) -> None:

  """

  Return a set of IDs directly or indirectly referenced by id.

  """

  ...



"""


Node Float To Int Items
^^^^^^^^^^^^^^^^^^^^^^^

:ROUND:           
  Round.

  Round the float up or down to the nearest integer.

:FLOOR:           
  Floor.

  Round the float down to the next smallest integer.

:CEILING:         
  Ceiling.

  Round the float up to the next largest integer.

:TRUNCATE:        
  Truncate.

  Round the float to the closest integer in the direction of zero (floor if positive; ceiling if negative).

.. _rna-enum-node-float-to-int-items:

"""

import typing



"""


Font Operators
**************

:func:`case_set`

:func:`case_toggle`

:func:`change_character`

:func:`change_spacing`

:func:`delete`

:func:`line_break`

:func:`move`

:func:`move_select`

:func:`open`

:func:`select_all`

:func:`select_word`

:func:`selection_set`

:func:`style_set`

:func:`style_toggle`

:func:`text_copy`

:func:`text_cut`

:func:`text_insert`

:func:`text_paste`

:func:`text_paste_from_file`

:func:`textbox_add`

:func:`textbox_remove`

:func:`unlink`

"""

import typing

def case_set(case: str = 'LOWER') -> None:

  """

  Set font case

  """

  ...

def case_toggle() -> None:

  """

  Toggle font case

  """

  ...

def change_character(delta: int = 1) -> None:

  """

  Change font character code

  """

  ...

def change_spacing(delta: float = 1.0) -> None:

  """

  Change font spacing

  """

  ...

def delete(type: str = 'PREVIOUS_CHARACTER') -> None:

  """

  Delete text by cursor position

  """

  ...

def line_break() -> None:

  """

  Insert line break at cursor position

  """

  ...

def move(type: str = 'LINE_BEGIN') -> None:

  """

  Move cursor to position type

  """

  ...

def move_select(type: str = 'LINE_BEGIN') -> None:

  """

  Move the cursor while selecting

  """

  ...

def open(filepath: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = True, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, relative_path: bool = True, display_type: str = 'THUMBNAIL', sort_method: str = '') -> None:

  """

  Load a new font from a file

  """

  ...

def select_all() -> None:

  """

  Select all text

  """

  ...

def select_word() -> None:

  """

  Select word under cursor

  """

  ...

def selection_set() -> None:

  """

  Set cursor selection

  """

  ...

def style_set(style: str = 'BOLD', clear: bool = False) -> None:

  """

  Set font style

  """

  ...

def style_toggle(style: str = 'BOLD') -> None:

  """

  Toggle font style

  """

  ...

def text_copy() -> None:

  """

  Copy selected text to clipboard

  """

  ...

def text_cut() -> None:

  """

  Cut selected text to clipboard

  """

  ...

def text_insert(text: str = '', accent: bool = False) -> None:

  """

  Insert text at cursor position

  """

  ...

def text_paste(selection: bool = False) -> None:

  """

  Paste text from clipboard

  """

  ...

def text_paste_from_file(filepath: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = True, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = True, filter_blenlib: bool = False, filemode: int = 9, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Paste contents from file

  """

  ...

def textbox_add() -> None:

  """

  Add a new text box

  """

  ...

def textbox_remove(index: int = 0) -> None:

  """

  Remove the text box

  """

  ...

def unlink() -> None:

  """

  Unlink active font data-block

  """

  ...



"""


Brush Gpencil Weight Types Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:WEIGHT:          
  Weight.

  Paint weight in active vertex group.

:BLUR:            
  Blur.

  Blur weight in active vertex group.

:AVERAGE:         
  Average.

  Average weight in active vertex group.

:SMEAR:           
  Smear.

  Smear weight in active vertex group.

.. _rna-enum-brush-gpencil-weight-types-items:

"""

import typing



"""


Proportional Falloff Curve Only Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:SMOOTH:          
  Smooth.

  Smooth falloff.

:SPHERE:          
  Sphere.

  Spherical falloff.

:ROOT:            
  Root.

  Root falloff.

:INVERSE_SQUARE:  
  Inverse Square.

  Inverse Square falloff.

:SHARP:           
  Sharp.

  Sharp falloff.

:LINEAR:          
  Linear.

  Linear falloff.

.. _rna-enum-proportional-falloff-curve-only-items:

"""

import typing



"""


Keyframe Paste Offset Value Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:LEFT_KEY:        
  Left Key.

  Paste keys with the first key matching the key left of the cursor.

:RIGHT_KEY:       
  Right Key.

  Paste keys with the last key matching the key right of the cursor.

:CURRENT_FRAME:   
  Current Frame Value.

  Paste keys relative to the value of the curve under the cursor.

:CURSOR_VALUE:    
  Cursor Value.

  Paste keys relative to the Y-Position of the cursor.

:NONE:            
  No Offset.

  Paste keys with the same value as they were copied.

.. _rna-enum-keyframe-paste-offset-value-items:

"""

import typing



"""


Node Geometry Curve Handle Side Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:LEFT:            
  Left.

  Use the left handles.

:RIGHT:           
  Right.

  Use the right handles.

.. _rna-enum-node-geometry-curve-handle-side-items:

"""

import typing



"""


Freestyle Module (freestyle)
****************************

This module provides data types of view map components (0D and 1D
elements), base classes for defining line stylization rules
(predicates, functions, chaining iterators, and stroke shaders),
as well as helper functions for style module writing.

"""

from . import utils

from . import types

from . import shaders

from . import predicates

from . import functions

from . import chainingiterators

import typing



"""


Context Access (bpy.context)
****************************

The context members available depend on the area of Blender which is currently being accessed.

Note that all context values are readonly,
but may be modified through the data API or by running operators


Global Context
==============

These properties are available in any contexts.

:data:`area`

:data:`asset_file_handle`

:data:`blend_data`

:data:`collection`

:data:`engine`

:data:`gizmo_group`

:data:`layer_collection`

:data:`mode`

:data:`preferences`

:data:`region`

:data:`region_data`

:data:`scene`

:data:`screen`

:data:`space_data`

:data:`tool_settings`

:data:`view_layer`

:data:`window`

:data:`window_manager`

:data:`workspace`


Buttons Context
===============

:data:`texture_slot`

:data:`world`

:data:`object`

:data:`mesh`

:data:`armature`

:data:`lattice`

:data:`curve`

:data:`meta_ball`

:data:`light`

:data:`speaker`

:data:`lightprobe`

:data:`camera`

:data:`material`

:data:`material_slot`

:data:`texture`

:data:`texture_user`

:data:`texture_user_property`

:data:`bone`

:data:`edit_bone`

:data:`pose_bone`

:data:`particle_system`

:data:`particle_system_editable`

:data:`particle_settings`

:data:`cloth`

:data:`soft_body`

:data:`fluid`

:data:`collision`

:data:`brush`

:data:`dynamic_paint`

:data:`line_style`

:data:`gpencil`

:data:`grease_pencil`

:data:`curves`

:data:`pointcloud`

:data:`volume`


Clip Context
============

:data:`edit_movieclip`

:data:`edit_mask`


File Context
============

:data:`active_file`

:data:`selected_files`

:data:`asset_library_ref`

:data:`selected_asset_files`

:data:`id`

:data:`selected_ids`


Image Context
=============

:data:`edit_image`


Node Context
============

:data:`selected_nodes`

:data:`active_node`


Screen Context
==============

:data:`visible_objects`

:data:`selectable_objects`

:data:`selected_objects`

:data:`editable_objects`

:data:`selected_editable_objects`

:data:`objects_in_mode`

:data:`objects_in_mode_unique_data`

:data:`visible_bones`

:data:`editable_bones`

:data:`selected_bones`

:data:`selected_editable_bones`

:data:`visible_pose_bones`

:data:`selected_pose_bones`

:data:`selected_pose_bones_from_active_object`

:data:`active_bone`

:data:`active_pose_bone`

:data:`active_object`

:data:`edit_object`

:data:`sculpt_object`

:data:`vertex_paint_object`

:data:`weight_paint_object`

:data:`image_paint_object`

:data:`particle_edit_object`

:data:`pose_object`

:data:`active_sequence_strip`

:data:`sequences`

:data:`selected_sequences`

:data:`selected_editable_sequences`

:data:`active_nla_track`

:data:`active_nla_strip`

:data:`selected_nla_strips`

:data:`selected_movieclip_tracks`

:data:`gpencil_data`

:data:`gpencil_data_owner`

:data:`annotation_data`

:data:`annotation_data_owner`

:data:`visible_gpencil_layers`

:data:`editable_gpencil_layers`

:data:`editable_gpencil_strokes`

:data:`active_gpencil_layer`

:data:`active_gpencil_frame`

:data:`active_annotation_layer`

:data:`active_operator`

:data:`active_action`

:data:`selected_visible_actions`

:data:`selected_editable_actions`

:data:`visible_fcurves`

:data:`editable_fcurves`

:data:`selected_visible_fcurves`

:data:`selected_editable_fcurves`

:data:`active_editable_fcurve`

:data:`selected_editable_keyframes`

:data:`ui_list`

:data:`property`


Sequencer Context
=================


Text Context
============

:data:`edit_text`


View3D Context
==============

"""

import typing

import bpy

area: bpy.types.Area = ...

asset_file_handle: bpy.types.FileSelectEntry = ...

"""

The file of an active asset. Avoid using this, it will be replaced by a proper AssetHandle design

"""

blend_data: bpy.types.BlendData = ...

collection: bpy.types.Collection = ...

engine: str = ...

gizmo_group: bpy.types.GizmoGroup = ...

layer_collection: bpy.types.LayerCollection = ...

mode: str = ...

preferences: bpy.types.Preferences = ...

region: bpy.types.Region = ...

region_data: bpy.types.RegionView3D = ...

scene: bpy.types.Scene = ...

screen: bpy.types.Screen = ...

space_data: bpy.types.Space = ...

"""

The current space, may be None in background-mode, when the cursor is outside the window or when using menu-search

"""

tool_settings: bpy.types.ToolSettings = ...

view_layer: bpy.types.ViewLayer = ...

window: bpy.types.Window = ...

window_manager: bpy.types.WindowManager = ...

workspace: bpy.types.WorkSpace = ...

texture_slot: bpy.types.TextureSlot = ...

world: bpy.types.World = ...

object: bpy.types.Object = ...

mesh: bpy.types.Mesh = ...

armature: bpy.types.Armature = ...

lattice: bpy.types.Lattice = ...

curve: bpy.types.Curve = ...

meta_ball: bpy.types.MetaBall = ...

light: bpy.types.Light = ...

speaker: bpy.types.Speaker = ...

lightprobe: bpy.types.LightProbe = ...

camera: bpy.types.Camera = ...

material: bpy.types.Material = ...

material_slot: bpy.types.MaterialSlot = ...

texture: bpy.types.Texture = ...

texture_user: bpy.types.ID = ...

texture_user_property: bpy.types.Property = ...

bone: bpy.types.Bone = ...

edit_bone: bpy.types.EditBone = ...

pose_bone: bpy.types.PoseBone = ...

particle_system: bpy.types.ParticleSystem = ...

particle_system_editable: bpy.types.ParticleSystem = ...

particle_settings: bpy.types.ParticleSettings = ...

cloth: bpy.types.ClothModifier = ...

soft_body: bpy.types.SoftBodyModifier = ...

fluid: bpy.types.FluidSimulationModifier = ...

collision: bpy.types.CollisionModifier = ...

brush: bpy.types.Brush = ...

dynamic_paint: bpy.types.DynamicPaintModifier = ...

line_style: bpy.types.FreestyleLineStyle = ...

gpencil: bpy.types.GreasePencil = ...

grease_pencil: bpy.types.GreasePencilv3 = ...

curves: typing.Any = ...

pointcloud: bpy.types.PointCloud = ...

volume: bpy.types.Volume = ...

edit_movieclip: bpy.types.MovieClip = ...

edit_mask: bpy.types.Mask = ...

active_file: bpy.types.FileSelectEntry = ...

selected_files: typing.Sequence[typing.Any] = ...

asset_library_ref: bpy.types.AssetLibraryReference = ...

selected_asset_files: typing.Sequence[typing.Any] = ...

id: bpy.types.ID = ...

selected_ids: typing.Sequence[typing.Any] = ...

edit_image: bpy.types.Image = ...

selected_nodes: typing.Sequence[typing.Any] = ...

active_node: bpy.types.Node = ...

visible_objects: typing.Sequence[typing.Any] = ...

selectable_objects: typing.Sequence[typing.Any] = ...

selected_objects: typing.Sequence[typing.Any] = ...

editable_objects: typing.Sequence[typing.Any] = ...

selected_editable_objects: typing.Sequence[typing.Any] = ...

objects_in_mode: typing.Sequence[typing.Any] = ...

objects_in_mode_unique_data: typing.Sequence[typing.Any] = ...

visible_bones: typing.Sequence[typing.Any] = ...

editable_bones: typing.Sequence[typing.Any] = ...

selected_bones: typing.Sequence[typing.Any] = ...

selected_editable_bones: typing.Sequence[typing.Any] = ...

visible_pose_bones: typing.Sequence[typing.Any] = ...

selected_pose_bones: typing.Sequence[typing.Any] = ...

selected_pose_bones_from_active_object: typing.Sequence[typing.Any] = ...

active_bone: bpy.types.EditBone = ...

active_pose_bone: bpy.types.PoseBone = ...

active_object: bpy.types.Object = ...

edit_object: bpy.types.Object = ...

sculpt_object: bpy.types.Object = ...

vertex_paint_object: bpy.types.Object = ...

weight_paint_object: bpy.types.Object = ...

image_paint_object: bpy.types.Object = ...

particle_edit_object: bpy.types.Object = ...

pose_object: bpy.types.Object = ...

active_sequence_strip: bpy.types.Sequence = ...

sequences: typing.Sequence[typing.Any] = ...

selected_sequences: typing.Sequence[typing.Any] = ...

selected_editable_sequences: typing.Sequence[typing.Any] = ...

active_nla_track: bpy.types.NlaTrack = ...

active_nla_strip: bpy.types.NlaStrip = ...

selected_nla_strips: typing.Sequence[typing.Any] = ...

selected_movieclip_tracks: typing.Sequence[typing.Any] = ...

gpencil_data: bpy.types.GreasePencil = ...

gpencil_data_owner: bpy.types.ID = ...

annotation_data: bpy.types.GreasePencil = ...

annotation_data_owner: bpy.types.ID = ...

visible_gpencil_layers: typing.Sequence[typing.Any] = ...

editable_gpencil_layers: typing.Sequence[typing.Any] = ...

editable_gpencil_strokes: typing.Sequence[typing.Any] = ...

active_gpencil_layer: typing.Sequence[typing.Any] = ...

active_gpencil_frame: typing.Sequence[typing.Any] = ...

active_annotation_layer: bpy.types.GPencilLayer = ...

active_operator: bpy.types.Operator = ...

active_action: bpy.types.Action = ...

selected_visible_actions: typing.Sequence[typing.Any] = ...

selected_editable_actions: typing.Sequence[typing.Any] = ...

visible_fcurves: typing.Sequence[typing.Any] = ...

editable_fcurves: typing.Sequence[typing.Any] = ...

selected_visible_fcurves: typing.Sequence[typing.Any] = ...

selected_editable_fcurves: typing.Sequence[typing.Any] = ...

active_editable_fcurve: bpy.types.FCurve = ...

selected_editable_keyframes: typing.Sequence[typing.Any] = ...

ui_list: bpy.types.UIList = ...

property: typing.Any = ...

"""

Get the property associated with a hovered button.
Returns a tuple of the datablock, data path to the property, and array index.

.. code::

  # Example inserting keyframe for the hovered property.
  active_property = bpy.context.property
  if active_property:
      datablock, data_path, index = active_property
      datablock.keyframe_insert(data_path=data_path, index=index, frame=1)

"""

edit_text: bpy.types.Text = ...



"""


Node Filter Items
^^^^^^^^^^^^^^^^^

:SOFTEN:          
  Soften.

:SHARPEN:         
  Box Sharpen.

  An aggressive sharpening filter.

:SHARPEN_DIAMOND: 
  Diamond Sharpen.

  A moderate sharpening filter.

:LAPLACE:         
  Laplace.

:SOBEL:           
  Sobel.

:PREWITT:         
  Prewitt.

:KIRSCH:          
  Kirsch.

:SHADOW:          
  Shadow.

.. _rna-enum-node-filter-items:

"""

import typing



"""


Node Map Range Items
^^^^^^^^^^^^^^^^^^^^

:LINEAR:          
  Linear.

  Linear interpolation between From Min and From Max values.

:STEPPED:         
  Stepped Linear.

  Stepped linear interpolation between From Min and From Max values.

:SMOOTHSTEP:      
  Smooth Step.

  Smooth Hermite edge interpolation between From Min and From Max values.

:SMOOTHERSTEP:    
  Smoother Step.

  Smoother Hermite edge interpolation between From Min and From Max values.

.. _rna-enum-node-map-range-items:

"""

import typing



"""


Uilist Layout Type Items
^^^^^^^^^^^^^^^^^^^^^^^^

:DEFAULT:         
  Default Layout.

  Use the default, multi-rows layout.

:COMPACT:         
  Compact Layout.

  Use the compact, single-row layout.

:GRID:            
  Grid Layout.

  Use the grid-based layout.

.. _rna-enum-uilist-layout-type-items:

"""

import typing



"""


GPU State Utilities (gpu.state)
*******************************

This module provides access to the gpu state.

:func:`framebuffer_active_get`

:func:`blend_get`

:func:`blend_set`

:func:`clip_distances_set`

:func:`color_mask_set`

:func:`depth_mask_get`

:func:`depth_mask_set`

:func:`depth_test_get`

:func:`depth_test_set`

:func:`face_culling_set`

:func:`front_facing_set`

:func:`line_width_get`

:func:`line_width_set`

:func:`point_size_set`

:func:`program_point_size_set`

:func:`scissor_get`

:func:`scissor_set`

:func:`scissor_test_set`

:func:`viewport_get`

:func:`viewport_set`

"""

import typing

def framebuffer_active_get(enable: typing.Any) -> None:

  """

  Return the active frame-buffer in context.

  """

  ...

def blend_get() -> None:

  """

  Current blending equation.

  """

  ...

def blend_set(mode: str) -> None:

  """

  Defines the fixed pipeline blending equation.

  """

  ...

def clip_distances_set(distances_enabled: int) -> None:

  """

  Sets the number of *gl_ClipDistance* planes used for clip geometry.

  """

  ...

def color_mask_set(r: typing.Any, g: typing.Any, b: typing.Any, a: typing.Any) -> None:

  """

  Enable or disable writing of frame buffer color components.

  """

  ...

def depth_mask_get() -> None:

  """

  Writing status in the depth component.

  """

  ...

def depth_mask_set(value: typing.Any) -> None:

  """

  Write to depth component.

  """

  ...

def depth_test_get() -> None:

  """

  Current depth_test equation.

  """

  ...

def depth_test_set(mode: str) -> None:

  """

  Defines the depth_test equation.

  """

  ...

def face_culling_set(culling: typing.Any) -> None:

  """

  Specify whether none, front-facing or back-facing facets can be culled.

  """

  ...

def front_facing_set(invert: typing.Any) -> None:

  """

  Specifies the orientation of front-facing polygons.

  """

  ...

def line_width_get() -> None:

  """

  Current width of rasterized lines.

  """

  ...

def line_width_set(width: typing.Any) -> None:

  """

  Specify the width of rasterized lines.

  """

  ...

def point_size_set(size: typing.Any) -> None:

  """

  Specify the diameter of rasterized points.

  """

  ...

def program_point_size_set(enable: bool) -> None:

  """

  If enabled, the derived point size is taken from the (potentially clipped) shader builtin gl_PointSize.

  """

  ...

def scissor_get() -> typing.Tuple[typing.Any, ...]:

  """

  Retrieve the scissors of the active framebuffer.
Note: Only valid between 'scissor_set' and a framebuffer rebind.

  """

  ...

def scissor_set(x: typing.Any, y: typing.Any, xsize: typing.Any, ysize: typing.Any) -> None:

  """

  Specifies the scissor area of the active framebuffer.
Note: The scissor state is not saved upon framebuffer rebind.

  """

  ...

def scissor_test_set(enable: bool) -> None:

  """

  Enable/disable scissor testing on the active framebuffer.

  """

  ...

def viewport_get() -> None:

  """

  Viewport of the active framebuffer.

  """

  ...

def viewport_set(x: typing.Any, y: typing.Any, xsize: typing.Any, ysize: typing.Any) -> None:

  """

  Specifies the viewport of the active framebuffer.
Note: The viewport state is not saved upon framebuffer rebind.

  """

  ...



"""


Node Tree Interface Item Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:SOCKET:          
  Socket.

:PANEL:           
  Panel.

.. _rna-enum-node-tree-interface-item-type-items:

"""

import typing



"""


Navigation Mode Items
^^^^^^^^^^^^^^^^^^^^^

:WALK:            
  Walk.

  Interactively walk or free navigate around the scene.

:FLY:             
  Fly.

  Use fly dynamics to navigate the scene.

.. _rna-enum-navigation-mode-items:

"""

import typing



"""


Spreadsheet Operators
*********************

:func:`add_row_filter_rule`

:func:`change_spreadsheet_data_source`

:func:`remove_row_filter_rule`

:func:`toggle_pin`

"""

import typing

def add_row_filter_rule() -> None:

  """

  Add a filter to remove rows from the displayed data

  """

  ...

def change_spreadsheet_data_source(component_type: int = 0, attribute_domain_type: int = 0) -> None:

  """

  Change visible data source in the spreadsheet

  """

  ...

def remove_row_filter_rule(index: int = 0) -> None:

  """

  Remove a row filter from the rules

  """

  ...

def toggle_pin() -> None:

  """

  Turn on or off pinning

  """

  ...



"""


BMesh Module (bmesh)
********************

This module provides access to blenders bmesh data structures.


Introduction
============

This API gives access the Blender's internal mesh editing API, featuring geometry connectivity data and
access to editing operations such as split, separate, collapse and dissolve.
The features exposed closely follow the C API,
giving Python access to the functions used by Blender's own mesh editing tools.

For an overview of BMesh data types and how they reference each other see:
`BMesh Design Document <https://wiki.blender.org/index.php/Dev:Source/Modeling/BMesh/Design>`_.

Note: **Disk** and **Radial** data is not exposed by the Python API since this is for internal use only.

Warning: TODO items are...

  * add access to BMesh **walkers**.

  * add custom-data manipulation functions add, remove or rename.


Example Script
==============

.. code::

  # This example assumes we have a mesh object selected

  import bpy
  import bmesh

  # Get the active mesh
  me = bpy.context.object.data


  # Get a BMesh representation
  bm = bmesh.new()   # create an empty BMesh
  bm.from_mesh(me)   # fill it in from a Mesh


  # Modify the BMesh, can do anything here...
  for v in bm.verts:
      v.co.x += 1.0


  # Finish up, write the bmesh back to the mesh
  bm.to_mesh(me)
  bm.free()  # free and prevent further access


Standalone Module
-----------------

The BMesh module is written to be standalone except for :mod:`mathutils`
which is used for vertex locations and normals.
The only other exception to this are when converting mesh data to and from :class:`bpy.types.Mesh`.


Mesh Access
===========

There are two ways to access BMesh data, you can create a new BMesh by converting a mesh from
:class:`bpy.types.BlendData.meshes` or by accessing the current Edit-Mode mesh.
See: :class:`bmesh.types.BMesh.from_mesh` and :mod:`bmesh.from_edit_mesh` respectively.

When explicitly converting from mesh data Python **owns** the data, that means that
the mesh only exists while Python holds a reference to it.
The script is responsible for putting it back into a mesh data-block when the edits are done.

Note that unlike :mod:`bpy`, a BMesh does not necessarily correspond to data in the currently open blend-file,
a BMesh can be created, edited and freed without the user ever seeing or having access to it.
Unlike Edit-Mode, the BMesh module can use multiple BMesh instances at once.

Take care when dealing with multiple BMesh instances since the mesh data can use a lot of memory.
While a mesh that the Python script owns will be freed when the script holds no references to it,
it's good practice to call :class:`bmesh.types.BMesh.free` which will remove all the mesh data immediately
and disable further access.


Edit-Mode Tessellation
----------------------

When writing scripts that operate on Edit-Mode data you will normally want to re-calculate the tessellation after
running the script, this needs to be called explicitly.
The BMesh itself does not store the triangulated faces, instead they are stored in the :class:`bpy.types.Mesh`,
to refresh tessellation triangles call :class:`bpy.types.Mesh.calc_loop_triangles`.


CustomData Access
=================

BMesh has a unified way to access mesh attributes such as UVs, vertex colors, shape keys, edge crease, etc.
This works by having a **layers** property on BMesh data sequences to access the custom data layers
which can then be used to access the actual data on each vert, edge, face or loop.

Here are some examples:

.. code:: python

  uv_lay = bm.loops.layers.uv.active

  for face in bm.faces:
      for loop in face.loops:
          uv = loop[uv_lay].uv
          print("Loop UV: %f, %f" % uv[:])
          vert = loop.vert
          print("Loop Vert: (%f,%f,%f)" % vert.co[:])

.. code:: python

  shape_lay = bm.verts.layers.shape["Key.001"]

  for vert in bm.verts:
      shape = vert[shape_lay]
      print("Vert Shape: %f, %f, %f" % (shape.x, shape.y, shape.z))

.. code:: python

  # in this example the active vertex group index is used,
  # this is stored in the object, not the BMesh
  group_index = obj.vertex_groups.active_index

  # only ever one deform weight layer
  dvert_lay = bm.verts.layers.deform.active

  for vert in bm.verts:
      dvert = vert[dvert_lay]

      if group_index in dvert:
          print("Weight %f" % dvert[group_index])
      else:
          print("Setting Weight")
          dvert[group_index] = 0.5


Keeping a Correct State
=======================

When modeling in Blender there are certain assumptions made about the state of the mesh:

* Hidden geometry isn't selected.

* When an edge is selected, its vertices are selected too.

* When a face is selected, its edges and vertices are selected.

* Duplicate edges / faces don't exist.

* Faces have at least three vertices.

To give developers flexibility these conventions are not enforced,
yet tools must leave the mesh in a valid state or else other tools may behave incorrectly.
Any errors that arise from not following these conventions is considered a bug in the script,
not a bug in Blender.


Selection / Flushing
--------------------

As mentioned above, it is possible to create an invalid selection state
(by selecting a state and then deselecting one of its vertices for example),
mostly the best way to solve this is to flush the selection
after performing a series of edits. This validates the selection state.


Module Functions
================

:func:`from_edit_mesh`

:func:`new`

:func:`update_edit_mesh`

"""

from . import utils

from . import types

from . import ops

from . import geometry

import typing

import bpy

def from_edit_mesh(self, mesh: bpy.types.Mesh) -> types.BMesh:

  """

  Return a BMesh from this mesh, currently the mesh must already be in editmode.

  """

  ...

def new(self, use_operators: bool = True) -> types.BMesh:

  ...

def update_edit_mesh(self, mesh: bpy.types.Mesh, loop_triangles: bool = True, destructive: bool = True) -> None:

  """

  Update the mesh after changes to the BMesh in editmode,
optionally recalculating n-gon tessellation.

  """

  ...



"""


Snap Animation Element Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:FRAME:           
  Frame.

  Snap to frame.

:SECOND:          
  Second.

  Snap to seconds.

:MARKER:          
  Nearest Marker.

  Snap to nearest marker.

.. _rna-enum-snap-animation-element-items:

"""

import typing



"""


Rigidbody Operators
*******************

:func:`bake_to_keyframes`

:func:`connect`

:func:`constraint_add`

:func:`constraint_remove`

:func:`mass_calculate`

:func:`object_add`

:func:`object_remove`

:func:`object_settings_copy`

:func:`objects_add`

:func:`objects_remove`

:func:`shape_change`

:func:`world_add`

:func:`world_remove`

"""

import typing

def bake_to_keyframes(frame_start: int = 1, frame_end: int = 250, step: int = 1) -> None:

  """

  Bake rigid body transformations of selected objects to keyframes

  """

  ...

def connect(con_type: str = 'FIXED', pivot_type: str = 'CENTER', connection_pattern: str = 'SELECTED_TO_ACTIVE') -> None:

  """

  Create rigid body constraints between selected rigid bodies

  """

  ...

def constraint_add(type: str = 'FIXED') -> None:

  """

  Add Rigid Body Constraint to active object

  """

  ...

def constraint_remove() -> None:

  """

  Remove Rigid Body Constraint from Object

  """

  ...

def mass_calculate(material: str = 'DEFAULT', density: float = 1.0) -> None:

  """

  Automatically calculate mass values for Rigid Body Objects based on volume

  """

  ...

def object_add(type: str = 'ACTIVE') -> None:

  """

  Add active object as Rigid Body

  """

  ...

def object_remove() -> None:

  """

  Remove Rigid Body settings from Object

  """

  ...

def object_settings_copy() -> None:

  """

  Copy Rigid Body settings from active object to selected

  """

  ...

def objects_add(type: str = 'ACTIVE') -> None:

  """

  Add selected objects as Rigid Bodies

  """

  ...

def objects_remove() -> None:

  """

  Remove selected objects from Rigid Body simulation

  """

  ...

def shape_change(type: str = 'MESH') -> None:

  """

  Change collision shapes for selected Rigid Body Objects

  """

  ...

def world_add() -> None:

  """

  Add Rigid Body simulation world to the current scene

  """

  ...

def world_remove() -> None:

  """

  Remove Rigid Body simulation world from the current scene

  """

  ...



"""


Node Clamp Items
^^^^^^^^^^^^^^^^

:MINMAX:          
  Min Max.

  Constrain value between min and max.

:RANGE:           
  Range.

  Constrain value between min and max, swapping arguments when min > max.

.. _rna-enum-node-clamp-items:

"""

import typing



"""


Space Image Mode All Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:VIEW:            
  View.

  View the image.

:UV:              
  UV Editor.

  UV edit in mesh editmode.

:PAINT:           
  Paint.

  2D image painting mode.

:MASK:            
  Mask.

  Mask editing.

.. _rna-enum-space-image-mode-all-items:

"""

import typing



"""


Collection Color Items
^^^^^^^^^^^^^^^^^^^^^^

:NONE:            
  None.

  Assign no color tag to the collection.

:COLOR_01:        
  Color 01.

:COLOR_02:        
  Color 02.

:COLOR_03:        
  Color 03.

:COLOR_04:        
  Color 04.

:COLOR_05:        
  Color 05.

:COLOR_06:        
  Color 06.

:COLOR_07:        
  Color 07.

:COLOR_08:        
  Color 08.

.. _rna-enum-collection-color-items:

"""

import typing



"""


Linestyle Color Modifier Type Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:ALONG_STROKE:    
  Along Stroke.

:CREASE_ANGLE:    
  Crease Angle.

:CURVATURE_3D:    
  Curvature 3D.

:DISTANCE_FROM_CAMERA:
  Distance from Camera.

:DISTANCE_FROM_OBJECT:
  Distance from Object.

:MATERIAL:        
  Material.

:NOISE:           
  Noise.

:TANGENT:         
  Tangent.

.. _rna-enum-linestyle-color-modifier-type-items:

"""

import typing



"""


Nla Mode Blend Items
^^^^^^^^^^^^^^^^^^^^

:REPLACE:         
  Replace.

  The strip values replace the accumulated results by amount specified by influence.

:COMBINE:         
  Combine.

  The strip values are combined with accumulated results by appropriately using addition, multiplication, or quaternion math, based on channel type.

.. _rna-enum-nla-mode-blend-items:

======================================================================

:ADD:             
  Add.

  Weighted result of strip is added to the accumulated results.

:SUBTRACT:        
  Subtract.

  Weighted result of strip is removed from the accumulated results.

:MULTIPLY:        
  Multiply.

  Weighted result of strip is multiplied with the accumulated results.

"""

import typing



"""


Shrinkwrap Face Cull Items
^^^^^^^^^^^^^^^^^^^^^^^^^^

:OFF:             
  Off.

  No culling.

:FRONT:           
  Front.

  No projection when in front of the face.

:BACK:            
  Back.

  No projection when behind the face.

.. _rna-enum-shrinkwrap-face-cull-items:

"""

import typing



"""


Modifier Shrinkwrap Mode Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:ON_SURFACE:      
  On Surface.

  The point is constrained to the surface of the target object, with distance offset towards the original point location.

:INSIDE:          
  Inside.

  The point is constrained to be inside the target object.

:OUTSIDE:         
  Outside.

  The point is constrained to be outside the target object.

:OUTSIDE_SURFACE: 
  Outside Surface.

  The point is constrained to the surface of the target object, with distance offset always to the outside, towards or away from the original location.

:ABOVE_SURFACE:   
  Above Surface.

  The point is constrained to the surface of the target object, with distance offset applied exactly along the target normal.

.. _rna-enum-modifier-shrinkwrap-mode-items:

"""

import typing



"""


Keying Flag Items
^^^^^^^^^^^^^^^^^

:INSERTKEY_NEEDED:
  Only Needed.

  Only insert keyframes where they're needed in the relevant F-Curves.

:INSERTKEY_VISUAL:
  Visual Keying.

  Insert keyframes based on 'visual transforms'.

:INSERTKEY_XYZ_TO_RGB:
  XYZ=RGB Colors.

  Color for newly added transformation F-Curves (Location, Rotation, Scale) and also Color is based on the transform axis.

.. _rna-enum-keying-flag-items:

"""

import typing



"""


Buttons Operators
*****************

:func:`clear_filter`

:func:`context_menu`

:func:`directory_browse`

:func:`file_browse`

:func:`start_filter`

:func:`toggle_pin`

"""

import typing

def clear_filter() -> None:

  """

  Clear the search filter

  """

  ...

def context_menu() -> None:

  """

  Display properties editor context_menu

  """

  ...

def directory_browse(directory: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = False, filter_blenlib: bool = False, filemode: int = 9, relative_path: bool = True, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Open a directory browser, hold Shift to open the file, Alt to browse containing directory

  """

  ...

def file_browse(filepath: str = '', hide_props_region: bool = True, check_existing: bool = False, filter_blender: bool = False, filter_backup: bool = False, filter_image: bool = False, filter_movie: bool = False, filter_python: bool = False, filter_font: bool = False, filter_sound: bool = False, filter_text: bool = False, filter_archive: bool = False, filter_btx: bool = False, filter_collada: bool = False, filter_alembic: bool = False, filter_usd: bool = False, filter_obj: bool = False, filter_volume: bool = False, filter_folder: bool = False, filter_blenlib: bool = False, filemode: int = 9, relative_path: bool = True, display_type: str = 'DEFAULT', sort_method: str = '') -> None:

  """

  Open a file browser, hold Shift to open the file, Alt to browse containing directory

  """

  ...

def start_filter() -> None:

  """

  Start entering filter text

  """

  ...

def toggle_pin() -> None:

  """

  Keep the current data-block displayed

  """

  ...



"""


Anim Operators
**************

:func:`change_frame`

:func:`channel_select_keys`

:func:`channel_view_pick`

:func:`channels_clean_empty`

:func:`channels_click`

:func:`channels_collapse`

:func:`channels_delete`

:func:`channels_editable_toggle`

:func:`channels_expand`

:func:`channels_fcurves_enable`

:func:`channels_group`

:func:`channels_move`

:func:`channels_rename`

:func:`channels_select_all`

:func:`channels_select_box`

:func:`channels_select_filter`

:func:`channels_setting_disable`

:func:`channels_setting_enable`

:func:`channels_setting_toggle`

:func:`channels_ungroup`

:func:`channels_view_selected`

:func:`clear_useless_actions`

:func:`copy_driver_button`

:func:`driver_button_add`

:func:`driver_button_edit`

:func:`driver_button_remove`

:func:`end_frame_set`

:func:`keyframe_clear_button`

:func:`keyframe_clear_v3d`

:func:`keyframe_delete`

:func:`keyframe_delete_button`

:func:`keyframe_delete_by_name`

:func:`keyframe_delete_v3d`

:func:`keyframe_insert`

:func:`keyframe_insert_button`

:func:`keyframe_insert_by_name`

:func:`keyframe_insert_menu`

:func:`keying_set_active_set`

:func:`keying_set_add`

:func:`keying_set_export`

:func:`keying_set_path_add`

:func:`keying_set_path_remove`

:func:`keying_set_remove`

:func:`keyingset_button_add`

:func:`keyingset_button_remove`

:func:`paste_driver_button`

:func:`previewrange_clear`

:func:`previewrange_set`

:func:`start_frame_set`

:func:`update_animated_transform_constraints`

"""

import typing

def change_frame(frame: float = 0.0, snap: bool = False) -> None:

  """

  Interactively change the current frame number

  """

  ...

def channel_select_keys(extend: bool = False) -> None:

  """

  Select all keyframes of channel under mouse

  """

  ...

def channel_view_pick(include_handles: bool = True, use_preview_range: bool = True) -> None:

  """

  Reset viewable area to show the channel under the cursor

  """

  ...

def channels_clean_empty() -> None:

  """

  Delete all empty animation data containers from visible data-blocks

  """

  ...

def channels_click(extend: bool = False, extend_range: bool = False, children_only: bool = False) -> None:

  """

  Handle mouse clicks over animation channels

  """

  ...

def channels_collapse(all: bool = True) -> None:

  """

  Collapse (close) all selected expandable animation channels

  """

  ...

def channels_delete() -> None:

  """

  Delete all selected animation channels

  """

  ...

def channels_editable_toggle(mode: str = 'TOGGLE', type: str = 'PROTECT') -> None:

  """

  Toggle editability of selected channels

  """

  ...

def channels_expand(all: bool = True) -> None:

  """

  Expand (open) all selected expandable animation channels

  """

  ...

def channels_fcurves_enable() -> None:

  """

  Clear 'disabled' tag from all F-Curves to get broken F-Curves working again

  """

  ...

def channels_group(name: str = 'New Group') -> None:

  """

  Add selected F-Curves to a new group

  """

  ...

def channels_move(direction: str = 'DOWN') -> None:

  """

  Rearrange selected animation channels

  """

  ...

def channels_rename() -> None:

  """

  Rename animation channel under mouse

  """

  ...

def channels_select_all(action: str = 'TOGGLE') -> None:

  """

  Toggle selection of all animation channels

  """

  ...

def channels_select_box(xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True, deselect: bool = False, extend: bool = True) -> None:

  """

  Select all animation channels within the specified region

  """

  ...

def channels_select_filter() -> None:

  """

  Start entering text which filters the set of channels shown to only include those with matching names

  """

  ...

def channels_setting_disable(mode: str = 'DISABLE', type: str = 'PROTECT') -> None:

  """

  Disable specified setting on all selected animation channels

  """

  ...

def channels_setting_enable(mode: str = 'ENABLE', type: str = 'PROTECT') -> None:

  """

  Enable specified setting on all selected animation channels

  """

  ...

def channels_setting_toggle(mode: str = 'TOGGLE', type: str = 'PROTECT') -> None:

  """

  Toggle specified setting on all selected animation channels

  """

  ...

def channels_ungroup() -> None:

  """

  Remove selected F-Curves from their current groups

  """

  ...

def channels_view_selected(include_handles: bool = True, use_preview_range: bool = True) -> None:

  """

  Reset viewable area to show the selected channels

  """

  ...

def clear_useless_actions(only_unused: bool = True) -> None:

  """

  Mark actions with no F-Curves for deletion after save and reload of file preserving "action libraries"

  """

  ...

def copy_driver_button() -> None:

  """

  Copy the driver for the highlighted button

  """

  ...

def driver_button_add() -> None:

  """

  Add driver for the property under the cursor

  """

  ...

def driver_button_edit() -> None:

  """

  Edit the drivers for the connected property represented by the highlighted button

  """

  ...

def driver_button_remove(all: bool = True) -> None:

  """

  Remove the driver(s) for the connected property(s) represented by the highlighted button

  """

  ...

def end_frame_set() -> None:

  """

  Set the current frame as the preview or scene end frame

  """

  ...

def keyframe_clear_button(all: bool = True) -> None:

  """

  Clear all keyframes on the currently active property

  """

  ...

def keyframe_clear_v3d(confirm: bool = True) -> None:

  """

  Remove all keyframe animation for selected objects

  """

  ...

def keyframe_delete(type: str = 'DEFAULT') -> None:

  """

  Delete keyframes on the current frame for all properties in the specified Keying Set

  """

  ...

def keyframe_delete_button(all: bool = True) -> None:

  """

  Delete current keyframe of current UI-active property

  """

  ...

def keyframe_delete_by_name(type: str = '') -> None:

  """

  Alternate access to 'Delete Keyframe' for keymaps to use

  """

  ...

def keyframe_delete_v3d(confirm: bool = True) -> None:

  """

  Remove keyframes on current frame for selected objects and bones

  """

  ...

def keyframe_insert(type: str = 'DEFAULT') -> None:

  """

  Insert keyframes on the current frame for all properties in the specified Keying Set

  """

  ...

def keyframe_insert_button(all: bool = True) -> None:

  """

  Insert a keyframe for current UI-active property

  """

  ...

def keyframe_insert_by_name(type: str = '') -> None:

  """

  Alternate access to 'Insert Keyframe' for keymaps to use

  """

  ...

def keyframe_insert_menu(type: str = 'DEFAULT', always_prompt: bool = False) -> None:

  """

  Insert Keyframes for specified Keying Set, with menu of available Keying Sets if undefined

  """

  ...

def keying_set_active_set(type: str = 'DEFAULT') -> None:

  """

  Set a new active keying set

  """

  ...

def keying_set_add() -> None:

  """

  Add a new (empty) keying set to the active Scene

  """

  ...

def keying_set_export(filepath: str = '', filter_folder: bool = True, filter_text: bool = True, filter_python: bool = True) -> None:

  """

  Export Keying Set to a Python script

  """

  ...

def keying_set_path_add() -> None:

  """

  Add empty path to active keying set

  """

  ...

def keying_set_path_remove() -> None:

  """

  Remove active Path from active keying set

  """

  ...

def keying_set_remove() -> None:

  """

  Remove the active keying set

  """

  ...

def keyingset_button_add(all: bool = True) -> None:

  """

  Add current UI-active property to current keying set

  """

  ...

def keyingset_button_remove() -> None:

  """

  Remove current UI-active property from current keying set

  """

  ...

def paste_driver_button() -> None:

  """

  Paste the driver in the internal clipboard to the highlighted button

  """

  ...

def previewrange_clear() -> None:

  """

  Clear preview range

  """

  ...

def previewrange_set(xmin: int = 0, xmax: int = 0, ymin: int = 0, ymax: int = 0, wait_for_input: bool = True) -> None:

  """

  Interactively define frame range used for playback

  """

  ...

def start_frame_set() -> None:

  """

  Set the current frame as the preview or scene start frame

  """

  ...

def update_animated_transform_constraints(use_convert_to_radians: bool = True) -> None:

  """

  Update f-curves/drivers affecting Transform constraints (use it with files from 2.70 and earlier)

  """

  ...



"""


Modifier Triangulate Ngon Method Items
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

:BEAUTY:          
  Beauty.

  Arrange the new triangles evenly (slow).

:CLIP:            
  Clip.

  Split the polygons with an ear clipping algorithm.

.. _rna-enum-modifier-triangulate-ngon-method-items:

"""

import typing



"""


BMesh Utilities (bmesh.utils)
*****************************

This module provides access to blenders bmesh data structures.

:func:`edge_rotate`

:func:`edge_split`

:func:`face_flip`

:func:`face_join`

:func:`face_split`

:func:`face_split_edgenet`

:func:`face_vert_separate`

:func:`loop_separate`

:func:`vert_collapse_edge`

:func:`vert_collapse_faces`

:func:`vert_dissolve`

:func:`vert_separate`

:func:`vert_splice`

"""

import typing

import bmesh

def edge_rotate(self, edge: bmesh.types.BMEdge, ccw: bool = False) -> bmesh.types.BMEdge:

  """

  Rotate the edge and return the newly created edge.
If rotating the edge fails, None will be returned.

  """

  ...

def edge_split(self, edge: bmesh.types.BMEdge, vert: bmesh.types.BMVert, fac: float) -> typing.Tuple[typing.Any, ...]:

  """

  Split an edge, return the newly created data.

  """

  ...

def face_flip(self, faces: typing.Any) -> None:

  """

  Flip the faces direction.

  """

  ...

def face_join(self, faces: bmesh.types.BMFace, remove: bool = True) -> bmesh.types.BMFace:

  """

  Joins a sequence of faces.

  """

  ...

def face_split(self, face: bmesh.types.BMFace, vert_a: bmesh.types.BMVert, vert_b: bmesh.types.BMVert, coords: typing.Sequence[float] = (), use_exist: bool = True, example: bmesh.types.BMEdge = None) -> typing.Any:

  """

  Face split with optional intermediate points.

  """

  ...

def face_split_edgenet(self, face: bmesh.types.BMFace, edgenet: bmesh.types.BMEdge) -> typing.Tuple[typing.Any, ...]:

  """

  Splits a face into any number of regions defined by an edgenet.

  Note: Regions defined by edges need to connect to the face, otherwise they're ignored as loose edges.

  """

  ...

def face_vert_separate(self, face: bmesh.types.BMFace, vert: bmesh.types.BMVert) -> None:

  """

  Rip a vertex in a face away and add a new vertex.

  Note: This is the same as loop_separate, and has only been added for convenience.

  """

  ...

def loop_separate(self, loop: bmesh.types.BMLoop) -> None:

  """

  Rip a vertex in a face away and add a new vertex.

  """

  ...

def vert_collapse_edge(self, vert: bmesh.types.BMVert, edge: bmesh.types.BMEdge) -> bmesh.types.BMEdge:

  """

  Collapse a vertex into an edge.

  """

  ...

def vert_collapse_faces(self, vert: bmesh.types.BMVert, edge: bmesh.types.BMEdge, fac: float, join_faces: bool) -> bmesh.types.BMEdge:

  """

  Collapses a vertex that has only two manifold edges onto a vertex it shares an edge with.

  """

  ...

def vert_dissolve(self, vert: bmesh.types.BMVert) -> bool:

  """

  Dissolve this vertex (will be removed).

  """

  ...

def vert_separate(self, vert: bmesh.types.BMVert, edges: bmesh.types.BMEdge) -> typing.Tuple[bmesh.types.BMVert, ...]:

  """

  Separate this vertex at every edge.

  """

  ...

def vert_splice(self, vert: bmesh.types.BMVert, vert_target: bmesh.types.BMVert) -> None:

  """

  Splice vert into vert_target.

  Note: The verts mustn't share an edge or face.

  """

  ...
